/* editable-entry.c generated by valac 0.22.1.2-49127, the Vala compiler
 * generated from editable-entry.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/
/* Boxes.EditableEntry is based on gnome-control-center CcEditableEntry*/

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>
#include <pango/pango.h>
#include <float.h>
#include <math.h>
#include <gdk/gdk.h>


#define BOXES_TYPE_EDITABLE_ENTRY (boxes_editable_entry_get_type ())
#define BOXES_EDITABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EDITABLE_ENTRY, BoxesEditableEntry))
#define BOXES_EDITABLE_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EDITABLE_ENTRY, BoxesEditableEntryClass))
#define BOXES_IS_EDITABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EDITABLE_ENTRY))
#define BOXES_IS_EDITABLE_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EDITABLE_ENTRY))
#define BOXES_EDITABLE_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EDITABLE_ENTRY, BoxesEditableEntryClass))

typedef struct _BoxesEditableEntry BoxesEditableEntry;
typedef struct _BoxesEditableEntryClass BoxesEditableEntryClass;
typedef struct _BoxesEditableEntryPrivate BoxesEditableEntryPrivate;

#define BOXES_EDITABLE_ENTRY_TYPE_PAGE (boxes_editable_entry_page_get_type ())
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define __vala_PangoFontDescription_free0(var) ((var == NULL) ? NULL : (var = (_vala_PangoFontDescription_free (var), NULL)))
#define _pango_attr_list_unref0(var) ((var == NULL) ? NULL : (var = (pango_attr_list_unref (var), NULL)))

struct _BoxesEditableEntry {
	GtkAlignment parent_instance;
	BoxesEditableEntryPrivate * priv;
	gboolean _editable;
};

struct _BoxesEditableEntryClass {
	GtkAlignmentClass parent_class;
};

struct _BoxesEditableEntryPrivate {
	gchar* _text;
	PangoWeight _weight;
	gboolean _weight_set;
	gdouble _scale;
	gboolean _scale_set;
	GtkNotebook* notebook;
	GtkLabel* label;
	GtkButton* button;
	GtkEntry* entry;
	gboolean in_stop_editing;
};

typedef enum  {
	BOXES_EDITABLE_ENTRY_PAGE_LABEL,
	BOXES_EDITABLE_ENTRY_PAGE_BUTTON,
	BOXES_EDITABLE_ENTRY_PAGE_ENTRY
} BoxesEditableEntryPage;


static gpointer boxes_editable_entry_parent_class = NULL;

#define EMPTY_TEXT "\xe2\x80\x94"
GType boxes_editable_entry_get_type (void) G_GNUC_CONST;
#define BOXES_EDITABLE_ENTRY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_EDITABLE_ENTRY, BoxesEditableEntryPrivate))
enum  {
	BOXES_EDITABLE_ENTRY_DUMMY_PROPERTY,
	BOXES_EDITABLE_ENTRY_TEXT,
	BOXES_EDITABLE_ENTRY_EDITABLE,
	BOXES_EDITABLE_ENTRY_SELECTABLE,
	BOXES_EDITABLE_ENTRY_WEIGHT_SET,
	BOXES_EDITABLE_ENTRY_SCALE,
	BOXES_EDITABLE_ENTRY_SCALE_SET
};
static GType boxes_editable_entry_page_get_type (void) G_GNUC_UNUSED;
static void boxes_editable_entry_update_entry_font (BoxesEditableEntry* self, GtkEntry* entry);
gboolean boxes_editable_entry_get_scale_set (BoxesEditableEntry* self);
gboolean boxes_editable_entry_get_weight_set (BoxesEditableEntry* self);
static PangoFontDescription* _vala_PangoFontDescription_copy (PangoFontDescription* self);
gdouble boxes_editable_entry_get_scale (BoxesEditableEntry* self);
static void _vala_PangoFontDescription_free (PangoFontDescription* self);
static void boxes_editable_entry_update_fonts (BoxesEditableEntry* self);
void boxes_editable_entry_start_editing (BoxesEditableEntry* self);
static void boxes_editable_entry_stop_editing (BoxesEditableEntry* self);
void boxes_editable_entry_set_text (BoxesEditableEntry* self, const gchar* value);
static void boxes_editable_entry_cancel_editing (BoxesEditableEntry* self);
const gchar* boxes_editable_entry_get_text (BoxesEditableEntry* self);
BoxesEditableEntry* boxes_editable_entry_new (void);
BoxesEditableEntry* boxes_editable_entry_construct (GType object_type);
static void __lambda3_ (BoxesEditableEntry* self);
static void ___lambda3__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void __lambda4_ (BoxesEditableEntry* self, GtkWidget* widget, GtkAllocation* allocation);
static void ___lambda4__gtk_widget_size_allocate (GtkWidget* _sender, GtkAllocation* allocation, gpointer self);
static void __lambda5_ (BoxesEditableEntry* self);
static void ___lambda5__gtk_entry_activate (GtkEntry* _sender, gpointer self);
static gboolean __lambda6_ (BoxesEditableEntry* self);
static gboolean ___lambda6__gtk_widget_focus_out_event (GtkWidget* _sender, GdkEventFocus* event, gpointer self);
static gboolean __lambda7_ (BoxesEditableEntry* self, GtkWidget* widget, GdkEventKey* event);
static gboolean ___lambda7__gtk_widget_key_press_event (GtkWidget* _sender, GdkEventKey* event, gpointer self);
static void __lambda8_ (BoxesEditableEntry* self, GtkWidget* entry);
static void ___lambda8__gtk_widget_style_updated (GtkWidget* _sender, gpointer self);
gboolean boxes_editable_entry_get_editable (BoxesEditableEntry* self);
void boxes_editable_entry_set_editable (BoxesEditableEntry* self, gboolean value);
gboolean boxes_editable_entry_get_selectable (BoxesEditableEntry* self);
void boxes_editable_entry_set_selectable (BoxesEditableEntry* self, gboolean value);
void boxes_editable_entry_set_weight_set (BoxesEditableEntry* self, gboolean value);
void boxes_editable_entry_set_scale (BoxesEditableEntry* self, gdouble value);
void boxes_editable_entry_set_scale_set (BoxesEditableEntry* self, gboolean value);
static void boxes_editable_entry_finalize (GObject* obj);
static void _vala_boxes_editable_entry_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_editable_entry_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);


static GType boxes_editable_entry_page_get_type (void) {
	static volatile gsize boxes_editable_entry_page_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_editable_entry_page_type_id__volatile)) {
		static const GEnumValue values[] = {{BOXES_EDITABLE_ENTRY_PAGE_LABEL, "BOXES_EDITABLE_ENTRY_PAGE_LABEL", "label"}, {BOXES_EDITABLE_ENTRY_PAGE_BUTTON, "BOXES_EDITABLE_ENTRY_PAGE_BUTTON", "button"}, {BOXES_EDITABLE_ENTRY_PAGE_ENTRY, "BOXES_EDITABLE_ENTRY_PAGE_ENTRY", "entry"}, {0, NULL, NULL}};
		GType boxes_editable_entry_page_type_id;
		boxes_editable_entry_page_type_id = g_enum_register_static ("BoxesEditableEntryPage", values);
		g_once_init_leave (&boxes_editable_entry_page_type_id__volatile, boxes_editable_entry_page_type_id);
	}
	return boxes_editable_entry_page_type_id__volatile;
}


static PangoFontDescription* _vala_PangoFontDescription_copy (PangoFontDescription* self) {
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	return g_boxed_copy (pango_font_description_get_type (), self);
#line 134 "editable-entry.c"
}


static gpointer __vala_PangoFontDescription_copy0 (gpointer self) {
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	return self ? _vala_PangoFontDescription_copy (self) : NULL;
#line 141 "editable-entry.c"
}


static void _vala_PangoFontDescription_free (PangoFontDescription* self) {
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_boxed_free (pango_font_description_get_type (), self);
#line 148 "editable-entry.c"
}


static void boxes_editable_entry_update_entry_font (BoxesEditableEntry* self, GtkEntry* entry) {
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp3_ = FALSE;
	GtkEntry* _tmp4_ = NULL;
	GtkEntry* _tmp5_ = NULL;
	PangoFontDescription* desc = NULL;
	GtkEntry* _tmp6_ = NULL;
	GtkStyleContext* _tmp7_ = NULL;
	GtkEntry* _tmp8_ = NULL;
	GtkStateFlags _tmp9_ = 0;
	PangoFontDescription* _tmp10_ = NULL;
	PangoFontDescription* _tmp11_ = NULL;
	gboolean _tmp12_ = FALSE;
	gboolean _tmp15_ = FALSE;
	GtkEntry* _tmp21_ = NULL;
	PangoFontDescription* _tmp22_ = NULL;
	GtkEntry* _tmp23_ = NULL;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_if_fail (self != NULL);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_if_fail (entry != NULL);
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp1_ = self->priv->_scale_set;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	if (!_tmp1_) {
#line 178 "editable-entry.c"
		gboolean _tmp2_ = FALSE;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp2_ = self->priv->_weight_set;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp0_ = !_tmp2_;
#line 184 "editable-entry.c"
	} else {
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp0_ = FALSE;
#line 188 "editable-entry.c"
	}
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp3_ = _tmp0_;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	if (_tmp3_) {
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		return;
#line 196 "editable-entry.c"
	}
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp4_ = entry;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_signal_handlers_block_by_func (_tmp4_, (void*) boxes_editable_entry_update_entry_font, self);
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp5_ = entry;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	gtk_widget_override_font ((GtkWidget*) _tmp5_, NULL);
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp6_ = entry;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp7_ = gtk_widget_get_style_context ((GtkWidget*) _tmp6_);
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp8_ = entry;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp9_ = gtk_widget_get_state_flags ((GtkWidget*) _tmp8_);
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp10_ = gtk_style_context_get_font (_tmp7_, _tmp9_);
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp11_ = __vala_PangoFontDescription_copy0 (_tmp10_);
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	desc = _tmp11_;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp12_ = self->priv->_weight_set;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	if (_tmp12_) {
#line 224 "editable-entry.c"
		PangoFontDescription* _tmp13_ = NULL;
		PangoWeight _tmp14_ = 0;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp13_ = desc;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp14_ = self->priv->_weight;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		pango_font_description_set_weight (_tmp13_, _tmp14_);
#line 233 "editable-entry.c"
	}
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp15_ = self->priv->_scale_set;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	if (_tmp15_) {
#line 239 "editable-entry.c"
		PangoFontDescription* _tmp16_ = NULL;
		gdouble _tmp17_ = 0.0;
		gdouble _tmp18_ = 0.0;
		PangoFontDescription* _tmp19_ = NULL;
		gint _tmp20_ = 0;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp16_ = desc;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp17_ = boxes_editable_entry_get_scale (self);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp18_ = _tmp17_;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp19_ = desc;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp20_ = pango_font_description_get_size (_tmp19_);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		pango_font_description_set_size (_tmp16_, (gint) (_tmp18_ * _tmp20_));
#line 257 "editable-entry.c"
	}
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp21_ = entry;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp22_ = desc;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	gtk_widget_override_font ((GtkWidget*) _tmp21_, _tmp22_);
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp23_ = entry;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_signal_handlers_unblock_by_func (_tmp23_, (void*) boxes_editable_entry_update_entry_font, self);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	__vala_PangoFontDescription_free0 (desc);
#line 271 "editable-entry.c"
}


static void boxes_editable_entry_update_fonts (BoxesEditableEntry* self) {
	PangoAttrList* attrs = NULL;
	PangoAttrList* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp6_ = FALSE;
	GtkLabel* _tmp10_ = NULL;
	PangoAttrList* _tmp11_ = NULL;
	GtkButton* _tmp12_ = NULL;
	GtkWidget* _tmp13_ = NULL;
	PangoAttrList* _tmp14_ = NULL;
	GtkEntry* _tmp15_ = NULL;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_if_fail (self != NULL);
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp0_ = pango_attr_list_new ();
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	attrs = _tmp0_;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp1_ = self->priv->_scale_set;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	if (_tmp1_) {
#line 296 "editable-entry.c"
		PangoAttrList* _tmp2_ = NULL;
		gdouble _tmp3_ = 0.0;
		gdouble _tmp4_ = 0.0;
		PangoAttribute* _tmp5_ = NULL;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp2_ = attrs;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp3_ = boxes_editable_entry_get_scale (self);
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp4_ = _tmp3_;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp5_ = pango_attr_scale_new (_tmp4_);
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		pango_attr_list_insert (_tmp2_, _tmp5_);
#line 311 "editable-entry.c"
	}
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp6_ = self->priv->_weight_set;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	if (_tmp6_) {
#line 317 "editable-entry.c"
		PangoAttrList* _tmp7_ = NULL;
		PangoWeight _tmp8_ = 0;
		PangoAttribute* _tmp9_ = NULL;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp7_ = attrs;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp8_ = self->priv->_weight;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp9_ = pango_attr_weight_new (_tmp8_);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		pango_attr_list_insert (_tmp7_, _tmp9_);
#line 329 "editable-entry.c"
	}
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp10_ = self->priv->label;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp11_ = attrs;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	gtk_label_set_attributes (_tmp10_, _tmp11_);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp12_ = self->priv->button;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp13_ = gtk_bin_get_child ((GtkBin*) _tmp12_);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp14_ = attrs;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	gtk_label_set_attributes (G_TYPE_CHECK_INSTANCE_TYPE (_tmp13_, GTK_TYPE_LABEL) ? ((GtkLabel*) _tmp13_) : NULL, _tmp14_);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp15_ = self->priv->entry;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	boxes_editable_entry_update_entry_font (self, _tmp15_);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_pango_attr_list_unref0 (attrs);
#line 351 "editable-entry.c"
}


void boxes_editable_entry_start_editing (BoxesEditableEntry* self) {
	GtkNotebook* _tmp0_ = NULL;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_if_fail (self != NULL);
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp0_ = self->priv->notebook;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_object_set (_tmp0_, "page", (gint) BOXES_EDITABLE_ENTRY_PAGE_ENTRY, NULL);
#line 363 "editable-entry.c"
}


static void boxes_editable_entry_stop_editing (BoxesEditableEntry* self) {
	gboolean _tmp0_ = FALSE;
	GtkNotebook* _tmp1_ = NULL;
	GtkEntry* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_if_fail (self != NULL);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp0_ = self->priv->in_stop_editing;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	if (_tmp0_) {
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		return;
#line 381 "editable-entry.c"
	}
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	self->priv->in_stop_editing = TRUE;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp1_ = self->priv->notebook;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_object_set (_tmp1_, "page", (gint) BOXES_EDITABLE_ENTRY_PAGE_BUTTON, NULL);
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp2_ = self->priv->entry;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp3_ = gtk_entry_get_text (_tmp2_);
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp4_ = _tmp3_;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	boxes_editable_entry_set_text (self, _tmp4_);
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_signal_emit_by_name (self, "editing-done");
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	self->priv->in_stop_editing = FALSE;
#line 401 "editable-entry.c"
}


static void boxes_editable_entry_cancel_editing (BoxesEditableEntry* self) {
	GtkEntry* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	GtkNotebook* _tmp3_ = NULL;
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_if_fail (self != NULL);
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp0_ = self->priv->entry;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp1_ = boxes_editable_entry_get_text (self);
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp2_ = _tmp1_;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	gtk_entry_set_text (_tmp0_, _tmp2_);
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp3_ = self->priv->notebook;
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_object_set (_tmp3_, "page", (gint) BOXES_EDITABLE_ENTRY_PAGE_BUTTON, NULL);
#line 424 "editable-entry.c"
}


static void __lambda3_ (BoxesEditableEntry* self) {
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	boxes_editable_entry_start_editing (self);
#line 431 "editable-entry.c"
}


static void ___lambda3__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	__lambda3_ (self);
#line 438 "editable-entry.c"
}


static void __lambda4_ (BoxesEditableEntry* self, GtkWidget* widget, GtkAllocation* allocation) {
	GtkAllocation alloc = {0};
	GtkWidget* _tmp0_ = NULL;
	GtkWidget* _tmp1_ = NULL;
	GtkAllocation _tmp2_ = {0};
	gint offset = 0;
	GtkAllocation _tmp3_ = {0};
	gint _tmp4_ = 0;
	GtkAllocation _tmp5_ = {0};
	gint _tmp6_ = 0;
	gint _tmp7_ = 0;
	GtkLabel* _tmp8_ = NULL;
	gint _tmp9_ = 0;
	gint _tmp10_ = 0;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_if_fail (widget != NULL);
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_if_fail (allocation != NULL);
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp0_ = widget;
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp1_ = gtk_widget_get_parent (_tmp0_);
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	gtk_widget_get_allocation (_tmp1_, &_tmp2_);
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	alloc = _tmp2_;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp3_ = *allocation;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp4_ = _tmp3_.x;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp5_ = alloc;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp6_ = _tmp5_.x;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	offset = _tmp4_ - _tmp6_;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp7_ = offset;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp8_ = self->priv->label;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_object_get ((GtkMisc*) _tmp8_, "xpad", &_tmp9_, NULL);
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp10_ = _tmp9_;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	if (_tmp7_ != _tmp10_) {
#line 488 "editable-entry.c"
		GtkLabel* _tmp11_ = NULL;
		gint _tmp12_ = 0;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp11_ = self->priv->label;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp12_ = offset;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		gtk_misc_set_padding ((GtkMisc*) _tmp11_, _tmp12_, 0);
#line 497 "editable-entry.c"
	}
}


static void ___lambda4__gtk_widget_size_allocate (GtkWidget* _sender, GtkAllocation* allocation, gpointer self) {
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	__lambda4_ (self, _sender, allocation);
#line 505 "editable-entry.c"
}


static void __lambda5_ (BoxesEditableEntry* self) {
#line 180 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	boxes_editable_entry_stop_editing (self);
#line 512 "editable-entry.c"
}


static void ___lambda5__gtk_entry_activate (GtkEntry* _sender, gpointer self) {
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	__lambda5_ (self);
#line 519 "editable-entry.c"
}


static gboolean __lambda6_ (BoxesEditableEntry* self) {
	gboolean result = FALSE;
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	boxes_editable_entry_stop_editing (self);
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	result = FALSE;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	return result;
#line 531 "editable-entry.c"
}


static gboolean ___lambda6__gtk_widget_focus_out_event (GtkWidget* _sender, GdkEventFocus* event, gpointer self) {
	gboolean result;
	result = __lambda6_ (self);
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	return result;
#line 540 "editable-entry.c"
}


static gboolean __lambda7_ (BoxesEditableEntry* self, GtkWidget* widget, GdkEventKey* event) {
	gboolean result = FALSE;
	GdkEventKey _tmp0_ = {0};
	guint _tmp1_ = 0U;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_val_if_fail (widget != NULL, FALSE);
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp0_ = *event;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp1_ = _tmp0_.keyval;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	if (_tmp1_ == ((guint) GDK_KEY_Escape)) {
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		boxes_editable_entry_cancel_editing (self);
#line 560 "editable-entry.c"
	}
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	result = FALSE;
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	return result;
#line 566 "editable-entry.c"
}


static gboolean ___lambda7__gtk_widget_key_press_event (GtkWidget* _sender, GdkEventKey* event, gpointer self) {
	gboolean result;
	result = __lambda7_ (self, _sender, event);
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	return result;
#line 575 "editable-entry.c"
}


static void __lambda8_ (BoxesEditableEntry* self, GtkWidget* entry) {
	GtkWidget* _tmp0_ = NULL;
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_if_fail (entry != NULL);
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp0_ = entry;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	boxes_editable_entry_update_entry_font (self, G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GTK_TYPE_ENTRY) ? ((GtkEntry*) _tmp0_) : NULL);
#line 587 "editable-entry.c"
}


static void ___lambda8__gtk_widget_style_updated (GtkWidget* _sender, gpointer self) {
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	__lambda8_ (self, _sender);
#line 594 "editable-entry.c"
}


BoxesEditableEntry* boxes_editable_entry_construct (GType object_type) {
	BoxesEditableEntry * self = NULL;
	GtkNotebook* _tmp0_ = NULL;
	GtkNotebook* _tmp1_ = NULL;
	GtkNotebook* _tmp2_ = NULL;
	GtkLabel* _tmp3_ = NULL;
	GtkLabel* _tmp4_ = NULL;
	GtkLabel* _tmp5_ = NULL;
	GtkNotebook* _tmp6_ = NULL;
	GtkLabel* _tmp7_ = NULL;
	GtkButton* _tmp8_ = NULL;
	GtkButton* _tmp9_ = NULL;
	GtkWidget* _tmp10_ = NULL;
	GtkButton* _tmp11_ = NULL;
	GtkButton* _tmp12_ = NULL;
	GtkButton* _tmp13_ = NULL;
	GtkNotebook* _tmp14_ = NULL;
	GtkButton* _tmp15_ = NULL;
	GtkButton* _tmp16_ = NULL;
	GtkButton* _tmp17_ = NULL;
	GtkWidget* _tmp18_ = NULL;
	GtkEntry* _tmp19_ = NULL;
	GtkNotebook* _tmp20_ = NULL;
	GtkEntry* _tmp21_ = NULL;
	GtkEntry* _tmp22_ = NULL;
	GtkEntry* _tmp23_ = NULL;
	GtkEntry* _tmp24_ = NULL;
	GtkEntry* _tmp25_ = NULL;
	GtkNotebook* _tmp26_ = NULL;
	GtkNotebook* _tmp27_ = NULL;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	self = (BoxesEditableEntry*) g_object_new (object_type, NULL);
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp0_ = (GtkNotebook*) gtk_notebook_new ();
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_object_ref_sink (_tmp0_);
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_g_object_unref0 (self->priv->notebook);
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	self->priv->notebook = _tmp0_;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp1_ = self->priv->notebook;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	gtk_notebook_set_show_tabs (_tmp1_, FALSE);
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp2_ = self->priv->notebook;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	gtk_notebook_set_show_border (_tmp2_, FALSE);
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp3_ = (GtkLabel*) gtk_label_new (EMPTY_TEXT);
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_object_ref_sink (_tmp3_);
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_g_object_unref0 (self->priv->label);
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	self->priv->label = _tmp3_;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp4_ = self->priv->label;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	gtk_label_set_ellipsize (_tmp4_, PANGO_ELLIPSIZE_END);
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp5_ = self->priv->label;
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	gtk_misc_set_alignment ((GtkMisc*) _tmp5_, 0.0f, 0.5f);
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp6_ = self->priv->notebook;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp7_ = self->priv->label;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	gtk_notebook_append_page (_tmp6_, (GtkWidget*) _tmp7_, NULL);
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp8_ = (GtkButton*) gtk_button_new_with_label (EMPTY_TEXT);
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_object_ref_sink (_tmp8_);
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_g_object_unref0 (self->priv->button);
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	self->priv->button = _tmp8_;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp9_ = self->priv->button;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp10_ = gtk_bin_get_child ((GtkBin*) _tmp9_);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	gtk_label_set_ellipsize (G_TYPE_CHECK_INSTANCE_TYPE (_tmp10_, GTK_TYPE_LABEL) ? ((GtkLabel*) _tmp10_) : NULL, PANGO_ELLIPSIZE_END);
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp11_ = self->priv->button;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	gtk_widget_set_receives_default ((GtkWidget*) _tmp11_, TRUE);
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp12_ = self->priv->button;
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	gtk_button_set_relief (_tmp12_, GTK_RELIEF_NONE);
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp13_ = self->priv->button;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	gtk_button_set_alignment (_tmp13_, 0.0f, 0.5f);
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp14_ = self->priv->notebook;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp15_ = self->priv->button;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	gtk_notebook_append_page (_tmp14_, (GtkWidget*) _tmp15_, NULL);
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp16_ = self->priv->button;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_signal_connect_object (_tmp16_, "clicked", (GCallback) ___lambda3__gtk_button_clicked, self, 0);
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp17_ = self->priv->button;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp18_ = gtk_bin_get_child ((GtkBin*) _tmp17_);
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_signal_connect_object (_tmp18_, "size-allocate", (GCallback) ___lambda4__gtk_widget_size_allocate, self, 0);
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp19_ = (GtkEntry*) gtk_entry_new ();
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_object_ref_sink (_tmp19_);
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_g_object_unref0 (self->priv->entry);
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	self->priv->entry = _tmp19_;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp20_ = self->priv->notebook;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp21_ = self->priv->entry;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	gtk_notebook_append_page (_tmp20_, (GtkWidget*) _tmp21_, NULL);
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp22_ = self->priv->entry;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_signal_connect_object (_tmp22_, "activate", (GCallback) ___lambda5__gtk_entry_activate, self, 0);
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp23_ = self->priv->entry;
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_signal_connect_object ((GtkWidget*) _tmp23_, "focus-out-event", (GCallback) ___lambda6__gtk_widget_focus_out_event, self, 0);
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp24_ = self->priv->entry;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_signal_connect_object ((GtkWidget*) _tmp24_, "key-press-event", (GCallback) ___lambda7__gtk_widget_key_press_event, self, 0);
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp25_ = self->priv->entry;
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_signal_connect_object ((GtkWidget*) _tmp25_, "style-updated", (GCallback) ___lambda8__gtk_widget_style_updated, self, 0);
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp26_ = self->priv->notebook;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_object_set (_tmp26_, "page", (gint) BOXES_EDITABLE_ENTRY_PAGE_LABEL, NULL);
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp27_ = self->priv->notebook;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	gtk_container_add ((GtkContainer*) self, (GtkWidget*) _tmp27_);
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	gtk_widget_show_all ((GtkWidget*) self);
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	return self;
#line 752 "editable-entry.c"
}


BoxesEditableEntry* boxes_editable_entry_new (void) {
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	return boxes_editable_entry_construct (BOXES_TYPE_EDITABLE_ENTRY);
#line 759 "editable-entry.c"
}


const gchar* boxes_editable_entry_get_text (BoxesEditableEntry* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp0_ = self->priv->_text;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	result = _tmp0_;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	return result;
#line 774 "editable-entry.c"
}


void boxes_editable_entry_set_text (BoxesEditableEntry* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	GtkEntry* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	const gchar* _tmp5_ = NULL;
	gboolean _tmp9_ = FALSE;
	GtkLabel* _tmp10_ = NULL;
	const gchar* _tmp11_ = NULL;
	GtkButton* _tmp12_ = NULL;
	GtkWidget* _tmp13_ = NULL;
	const gchar* _tmp14_ = NULL;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_if_fail (self != NULL);
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp0_ = value;
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_g_free0 (self->priv->_text);
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	self->priv->_text = _tmp1_;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp2_ = self->priv->entry;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp3_ = value;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	gtk_entry_set_text (_tmp2_, _tmp3_);
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp5_ = value;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	if (_tmp5_ == NULL) {
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp4_ = TRUE;
#line 813 "editable-entry.c"
	} else {
		const gchar* _tmp6_ = NULL;
		gint _tmp7_ = 0;
		gint _tmp8_ = 0;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp6_ = value;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp7_ = strlen (_tmp6_);
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp8_ = _tmp7_;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp4_ = _tmp8_ == 0;
#line 826 "editable-entry.c"
	}
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp9_ = _tmp4_;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	if (_tmp9_) {
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		value = EMPTY_TEXT;
#line 834 "editable-entry.c"
	}
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp10_ = self->priv->label;
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp11_ = value;
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	gtk_label_set_label (_tmp10_, _tmp11_);
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp12_ = self->priv->button;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp13_ = gtk_bin_get_child ((GtkBin*) _tmp12_);
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp14_ = value;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	gtk_label_set_label (G_TYPE_CHECK_INSTANCE_TYPE (_tmp13_, GTK_TYPE_LABEL) ? ((GtkLabel*) _tmp13_) : NULL, _tmp14_);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_object_notify ((GObject *) self, "text");
#line 852 "editable-entry.c"
}


gboolean boxes_editable_entry_get_editable (BoxesEditableEntry* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp0_ = self->_editable;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	result = _tmp0_;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	return result;
#line 867 "editable-entry.c"
}


void boxes_editable_entry_set_editable (BoxesEditableEntry* self, gboolean value) {
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
	BoxesEditableEntryPage _tmp3_ = 0;
	gboolean _tmp4_ = FALSE;
	gboolean _tmp5_ = FALSE;
	GtkNotebook* _tmp6_ = NULL;
	BoxesEditableEntryPage _tmp7_ = 0;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_if_fail (self != NULL);
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp0_ = value;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp1_ = self->_editable;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	if (_tmp0_ == _tmp1_) {
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		return;
#line 890 "editable-entry.c"
	}
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp2_ = value;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	self->_editable = _tmp2_;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp4_ = boxes_editable_entry_get_editable (self);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp5_ = _tmp4_;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	if (_tmp5_) {
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp3_ = BOXES_EDITABLE_ENTRY_PAGE_BUTTON;
#line 904 "editable-entry.c"
	} else {
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp3_ = BOXES_EDITABLE_ENTRY_PAGE_LABEL;
#line 908 "editable-entry.c"
	}
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp6_ = self->priv->notebook;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp7_ = _tmp3_;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_object_set (_tmp6_, "page", (gint) _tmp7_, NULL);
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_object_notify ((GObject *) self, "editable");
#line 918 "editable-entry.c"
}


gboolean boxes_editable_entry_get_selectable (BoxesEditableEntry* self) {
	gboolean result;
	GtkLabel* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp0_ = self->priv->label;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp1_ = gtk_label_get_selectable (_tmp0_);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp2_ = _tmp1_;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	result = _tmp2_;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	return result;
#line 939 "editable-entry.c"
}


void boxes_editable_entry_set_selectable (BoxesEditableEntry* self, gboolean value) {
	gboolean _tmp0_ = FALSE;
	GtkLabel* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
	GtkLabel* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_if_fail (self != NULL);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp0_ = value;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp1_ = self->priv->label;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp2_ = gtk_label_get_selectable (_tmp1_);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp3_ = _tmp2_;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	if (_tmp0_ == _tmp3_) {
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		return;
#line 964 "editable-entry.c"
	}
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp4_ = self->priv->label;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp5_ = value;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	gtk_label_set_selectable (_tmp4_, _tmp5_);
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_object_notify ((GObject *) self, "selectable");
#line 974 "editable-entry.c"
}


gboolean boxes_editable_entry_get_weight_set (BoxesEditableEntry* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp0_ = self->priv->_weight_set;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	result = _tmp0_;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	return result;
#line 989 "editable-entry.c"
}


void boxes_editable_entry_set_weight_set (BoxesEditableEntry* self, gboolean value) {
	gboolean _tmp0_ = FALSE;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_if_fail (self != NULL);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp0_ = value;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	self->priv->_weight_set = _tmp0_;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_object_notify ((GObject *) self, "weight-set");
#line 1003 "editable-entry.c"
}


gdouble boxes_editable_entry_get_scale (BoxesEditableEntry* self) {
	gdouble result;
	gdouble _tmp0_ = 0.0;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_val_if_fail (self != NULL, 0.0);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp0_ = self->priv->_scale;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	result = _tmp0_;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	return result;
#line 1018 "editable-entry.c"
}


void boxes_editable_entry_set_scale (BoxesEditableEntry* self, gdouble value) {
	gboolean _tmp0_ = FALSE;
	gdouble _tmp1_ = 0.0;
	gdouble _tmp2_ = 0.0;
	gboolean _tmp4_ = FALSE;
	gdouble _tmp5_ = 0.0;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_if_fail (self != NULL);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp1_ = value;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp2_ = self->priv->_scale;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	if (_tmp1_ == _tmp2_) {
#line 1036 "editable-entry.c"
		gboolean _tmp3_ = FALSE;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp3_ = self->priv->_scale_set;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp0_ = _tmp3_;
#line 1042 "editable-entry.c"
	} else {
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		_tmp0_ = FALSE;
#line 1046 "editable-entry.c"
	}
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp4_ = _tmp0_;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	if (_tmp4_) {
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		return;
#line 1054 "editable-entry.c"
	}
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp5_ = value;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	self->priv->_scale = _tmp5_;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	boxes_editable_entry_set_scale_set (self, TRUE);
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	boxes_editable_entry_update_fonts (self);
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_object_notify ((GObject *) self, "scale");
#line 1066 "editable-entry.c"
}


gboolean boxes_editable_entry_get_scale_set (BoxesEditableEntry* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp0_ = self->priv->_scale_set;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	result = _tmp0_;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	return result;
#line 1081 "editable-entry.c"
}


void boxes_editable_entry_set_scale_set (BoxesEditableEntry* self, gboolean value) {
	gboolean _tmp0_ = FALSE;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_return_if_fail (self != NULL);
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_tmp0_ = value;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	self->priv->_scale_set = _tmp0_;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_object_notify ((GObject *) self, "scale-set");
#line 1095 "editable-entry.c"
}


static void boxes_editable_entry_class_init (BoxesEditableEntryClass * klass) {
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	boxes_editable_entry_parent_class = g_type_class_peek_parent (klass);
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_type_class_add_private (klass, sizeof (BoxesEditableEntryPrivate));
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_editable_entry_get_property;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_editable_entry_set_property;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_editable_entry_finalize;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_EDITABLE_ENTRY_TEXT, g_param_spec_string ("text", "text", "text", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_EDITABLE_ENTRY_EDITABLE, g_param_spec_boolean ("editable", "editable", "editable", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_EDITABLE_ENTRY_SELECTABLE, g_param_spec_boolean ("selectable", "selectable", "selectable", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_EDITABLE_ENTRY_WEIGHT_SET, g_param_spec_boolean ("weight-set", "weight-set", "weight-set", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_EDITABLE_ENTRY_SCALE, g_param_spec_double ("scale", "scale", "scale", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_EDITABLE_ENTRY_SCALE_SET, g_param_spec_boolean ("scale-set", "scale-set", "scale-set", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	g_signal_new ("editing_done", BOXES_TYPE_EDITABLE_ENTRY, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 1124 "editable-entry.c"
}


static void boxes_editable_entry_instance_init (BoxesEditableEntry * self) {
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	self->priv = BOXES_EDITABLE_ENTRY_GET_PRIVATE (self);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	self->priv->_weight = PANGO_WEIGHT_NORMAL;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	self->priv->_scale = 1.0;
#line 1135 "editable-entry.c"
}


static void boxes_editable_entry_finalize (GObject* obj) {
	BoxesEditableEntry * self;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_EDITABLE_ENTRY, BoxesEditableEntry);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_g_free0 (self->priv->_text);
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_g_object_unref0 (self->priv->notebook);
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_g_object_unref0 (self->priv->label);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_g_object_unref0 (self->priv->button);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	_g_object_unref0 (self->priv->entry);
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	G_OBJECT_CLASS (boxes_editable_entry_parent_class)->finalize (obj);
#line 1155 "editable-entry.c"
}


GType boxes_editable_entry_get_type (void) {
	static volatile gsize boxes_editable_entry_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_editable_entry_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesEditableEntryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_editable_entry_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesEditableEntry), 0, (GInstanceInitFunc) boxes_editable_entry_instance_init, NULL };
		GType boxes_editable_entry_type_id;
		boxes_editable_entry_type_id = g_type_register_static (GTK_TYPE_ALIGNMENT, "BoxesEditableEntry", &g_define_type_info, 0);
		g_once_init_leave (&boxes_editable_entry_type_id__volatile, boxes_editable_entry_type_id);
	}
	return boxes_editable_entry_type_id__volatile;
}


static void _vala_boxes_editable_entry_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesEditableEntry * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_EDITABLE_ENTRY, BoxesEditableEntry);
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	switch (property_id) {
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		case BOXES_EDITABLE_ENTRY_TEXT:
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		g_value_set_string (value, boxes_editable_entry_get_text (self));
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		break;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		case BOXES_EDITABLE_ENTRY_EDITABLE:
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		g_value_set_boolean (value, boxes_editable_entry_get_editable (self));
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		break;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		case BOXES_EDITABLE_ENTRY_SELECTABLE:
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		g_value_set_boolean (value, boxes_editable_entry_get_selectable (self));
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		break;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		case BOXES_EDITABLE_ENTRY_WEIGHT_SET:
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		g_value_set_boolean (value, boxes_editable_entry_get_weight_set (self));
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		break;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		case BOXES_EDITABLE_ENTRY_SCALE:
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		g_value_set_double (value, boxes_editable_entry_get_scale (self));
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		break;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		case BOXES_EDITABLE_ENTRY_SCALE_SET:
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		g_value_set_boolean (value, boxes_editable_entry_get_scale_set (self));
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		break;
#line 1212 "editable-entry.c"
		default:
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		break;
#line 1218 "editable-entry.c"
	}
}


static void _vala_boxes_editable_entry_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesEditableEntry * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_EDITABLE_ENTRY, BoxesEditableEntry);
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
	switch (property_id) {
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		case BOXES_EDITABLE_ENTRY_TEXT:
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		boxes_editable_entry_set_text (self, g_value_get_string (value));
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		break;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		case BOXES_EDITABLE_ENTRY_EDITABLE:
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		boxes_editable_entry_set_editable (self, g_value_get_boolean (value));
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		break;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		case BOXES_EDITABLE_ENTRY_SELECTABLE:
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		boxes_editable_entry_set_selectable (self, g_value_get_boolean (value));
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		break;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		case BOXES_EDITABLE_ENTRY_WEIGHT_SET:
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		boxes_editable_entry_set_weight_set (self, g_value_get_boolean (value));
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		break;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		case BOXES_EDITABLE_ENTRY_SCALE:
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		boxes_editable_entry_set_scale (self, g_value_get_double (value));
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		break;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		case BOXES_EDITABLE_ENTRY_SCALE_SET:
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		boxes_editable_entry_set_scale_set (self, g_value_get_boolean (value));
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		break;
#line 1264 "editable-entry.c"
		default:
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/editable-entry.vala"
		break;
#line 1270 "editable-entry.c"
	}
}



