/* util-app.c generated by valac 0.22.1.2-49127, the Vala compiler
 * generated from util-app.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gdk/gdk.h>
#include <clutter/clutter.h>
#include <float.h>
#include <math.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>
#include <libcommon.h>
#include <libxml/parser.h>
#include <libxml/tree.h>
#include <libxml/xpath.h>
#include <clutter-gtk/clutter-gtk.h>
#include <gio/gio.h>
#include <osinfo/osinfo.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <libvirt-gobject/libvirt-gobject.h>
#include <config.h>
#include <sys/socket.h>
#include <errno.h>
#include <netinet/in.h>
#include <linux/if.h>
#include <sys/ioctl.h>
#include <glib/gi18n-lib.h>
#include <glib/gstdio.h>
#include <unistd.h>
#include <cairo.h>
#include <libgd/gd.h>

#define _gtk_widget_path_unref0(var) ((var == NULL) ? NULL : (var = (gtk_widget_path_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _Block62Data Block62Data;
#define _gtk_tree_path_free0(var) ((var == NULL) ? NULL : (var = (gtk_tree_path_free (var), NULL)))
typedef struct _Block63Data Block63Data;
#define _xmlFreeParserCtxt0(var) ((var == NULL) ? NULL : (var = (xmlFreeParserCtxt (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _xmlXPathFreeContext0(var) ((var == NULL) ? NULL : (var = (xmlXPathFreeContext (var), NULL)))
typedef struct _Block64Data Block64Data;

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UI, BoxesUIClass))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_IS_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UI))
#define BOXES_UI_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UI, BoxesUIClass))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIClass BoxesUIClass;

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;
typedef struct _BoxesUIPrivate BoxesUIPrivate;
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_CLUTTER_WIDGET (boxes_clutter_widget_get_type ())
#define BOXES_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidget))
#define BOXES_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))
#define BOXES_IS_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_IS_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_CLUTTER_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))

typedef struct _BoxesClutterWidget BoxesClutterWidget;
typedef struct _BoxesClutterWidgetClass BoxesClutterWidgetClass;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_REVEALER (boxes_revealer_get_type ())
#define BOXES_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_REVEALER, BoxesRevealer))
#define BOXES_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_REVEALER, BoxesRevealerClass))
#define BOXES_IS_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_REVEALER))
#define BOXES_IS_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_REVEALER))
#define BOXES_REVEALER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_REVEALER, BoxesRevealerClass))

typedef struct _BoxesRevealer BoxesRevealer;
typedef struct _BoxesRevealerClass BoxesRevealerClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;

#define BOXES_TYPE_COLLECTION_FILTER (boxes_collection_filter_get_type ())
#define BOXES_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilter))
#define BOXES_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))
#define BOXES_IS_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_IS_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_COLLECTION_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))

typedef struct _BoxesCollectionFilter BoxesCollectionFilter;
typedef struct _BoxesCollectionFilterClass BoxesCollectionFilterClass;

#define BOXES_TYPE_COLLECTION_VIEW (boxes_collection_view_get_type ())
#define BOXES_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView))
#define BOXES_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))
#define BOXES_IS_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_IS_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_COLLECTION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))

typedef struct _BoxesCollectionView BoxesCollectionView;
typedef struct _BoxesCollectionViewClass BoxesCollectionViewClass;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _BoxesCheckSelinuxContextDefaultData BoxesCheckSelinuxContextDefaultData;
typedef struct _BoxesCheckLibvirtKvmData BoxesCheckLibvirtKvmData;
typedef struct _BoxesCheckCpuVtCapabilityData BoxesCheckCpuVtCapabilityData;
typedef struct _BoxesCheckModuleKvmLoadedData BoxesCheckModuleKvmLoadedData;
typedef struct _BoxesCheckStoragePoolData BoxesCheckStoragePoolData;
typedef struct _Block65Data Block65Data;
typedef struct _BoxesCopyFileData BoxesCopyFileData;

#define BOXES_TYPE_CPU_ARCH_COMPATIBILITY (boxes_cpu_arch_compatibility_get_type ())

#define BOXES_FDO_TYPE_TIMEDATE1 (boxes_fdo_timedate1_get_type ())
#define BOXES_FDO_TIMEDATE1(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_FDO_TYPE_TIMEDATE1, BoxesFdotimedate1))
#define BOXES_FDO_IS_TIMEDATE1(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_FDO_TYPE_TIMEDATE1))
#define BOXES_FDO_TIMEDATE1_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_FDO_TYPE_TIMEDATE1, BoxesFdotimedate1Iface))

typedef struct _BoxesFdotimedate1 BoxesFdotimedate1;
typedef struct _BoxesFdotimedate1Iface BoxesFdotimedate1Iface;

#define BOXES_FDO_TYPE_TIMEDATE1_PROXY (boxes_fdo_timedate1_proxy_get_type ())
typedef GDBusProxy BoxesFdotimedate1Proxy;
typedef GDBusProxyClass BoxesFdotimedate1ProxyClass;

struct _Block62Data {
	int _ref_count_;
	GtkTreeView* tree_view;
};

struct _Block63Data {
	int _ref_count_;
	GtkIconView* icon_view;
};

struct _Block64Data {
	int _ref_count_;
	ClutterActor* actor;
};

struct _BoxesUI {
	GObject parent_instance;
	BoxesUIPrivate * priv;
};

struct _BoxesUIClass {
	GObjectClass parent_class;
	void (*ui_state_changed) (BoxesUI* self);
	ClutterActor* (*get_actor) (BoxesUI* self);
};

struct _BoxesApp {
	BoxesUI parent_instance;
	BoxesAppPrivate * priv;
	GtkApplicationWindow* window;
	GtkNotebook* notebook;
	BoxesClutterWidget* embed;
	ClutterStage* stage;
	ClutterBinLayout* stage_bin;
	ClutterActor* overlay_bin_actor;
	ClutterBinLayout* overlay_bin;
	BoxesCollectionItem* current_item;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesRevealer* sidebar_revealer;
	BoxesRevealer* searchbar_revealer;
	BoxesSidebar* sidebar;
	BoxesSelectionbar* selectionbar;
	guint duration;
	GSettings* settings;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	BoxesCollection* collection;
	BoxesCollectionFilter* filter;
	BoxesCollectionView* view;
};

struct _BoxesAppClass {
	BoxesUIClass parent_class;
};

typedef void (*BoxesActorFunc) (ClutterActor* actor, void* user_data);
struct _BoxesCheckSelinuxContextDefaultData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	gchar* diagnosis;
	gboolean result;
	gchar* _tmp0_;
	gchar* standard_output;
	gchar** argv;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar** _tmp6_;
	gint argv_length1;
	gint _argv_size_;
	gchar** _tmp7_;
	gint _tmp7__length1;
	gchar* _tmp8_;
	const gchar* _tmp9_;
	gint _tmp10_;
	gint _tmp11_;
	gchar** _tmp12_;
	gint _tmp12__length1;
	gchar* _tmp13_;
	gchar* _tmp14_;
	const gchar* _tmp15_;
	gchar** _tmp16_;
	gint _tmp16__length1;
	gchar* _tmp17_;
	gchar* _tmp18_;
	gchar* _tmp19_;
	GError* _error_;
	const gchar* _tmp20_;
	gchar* _tmp21_;
	GError* _vala1__error_;
	GError* _tmp22_;
	const gchar* _tmp23_;
	GError * _inner_error_;
};

struct _BoxesCheckLibvirtKvmData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	gboolean result;
	gchar* standard_output;
	gchar** argv;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar** _tmp2_;
	gint argv_length1;
	gint _argv_size_;
	gchar** _tmp3_;
	gint _tmp3__length1;
	gchar* _tmp4_;
	gchar* kvm;
	const gchar* _tmp5_;
	gchar* _tmp6_;
	const gchar* _tmp7_;
	gint _tmp8_;
	gint _tmp9_;
	GError* _error_;
	GError* _vala1__error_;
	GError* _tmp10_;
	const gchar* _tmp11_;
	GError * _inner_error_;
};

struct _BoxesCheckCpuVtCapabilityData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	gboolean result;
	gboolean _result_;
	GFile* file;
	GFile* _tmp0_;
	GFileInputStream* _tmp1_;
	GFile* _tmp2_;
	GFileInputStream* _tmp3_;
	GDataInputStream* stream;
	GFileInputStream* _tmp4_;
	GDataInputStream* _tmp5_;
	GDataInputStream* _tmp6_;
	gchar* line;
	gchar* _tmp7_;
	GDataInputStream* _tmp8_;
	gchar* _tmp9_;
	const gchar* _tmp10_;
	const gchar* _tmp11_;
	gboolean _tmp12_;
	gboolean _tmp13_;
	GError* _error_;
	const gchar* _tmp14_;
	gboolean _tmp15_;
	gchar* _tmp16_;
	gchar* _tmp17_;
	gchar* _tmp18_;
	gchar* _tmp19_;
	GError * _inner_error_;
};

struct _BoxesCheckModuleKvmLoadedData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	gboolean result;
	gboolean _result_;
	GFile* file;
	GFile* _tmp0_;
	GFileInputStream* _tmp1_;
	GFile* _tmp2_;
	GFileInputStream* _tmp3_;
	GDataInputStream* stream;
	GFileInputStream* _tmp4_;
	GDataInputStream* _tmp5_;
	GDataInputStream* _tmp6_;
	gchar* line;
	gchar* _tmp7_;
	GDataInputStream* _tmp8_;
	gchar* _tmp9_;
	const gchar* _tmp10_;
	const gchar* _tmp11_;
	gboolean _tmp12_;
	gboolean _tmp13_;
	GError* _error_;
	const gchar* _tmp14_;
	gboolean _tmp15_;
	gchar* _tmp16_;
	gchar* _tmp17_;
	gchar* _tmp18_;
	gchar* _tmp19_;
	GError * _inner_error_;
};

struct _BoxesCheckStoragePoolData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	gchar* diagnosis;
	gboolean result;
	gchar* pool_path;
	gchar* _tmp0_;
	gchar* standard_output;
	gchar** argv;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar** _tmp4_;
	gint argv_length1;
	gint _argv_size_;
	gchar** _tmp5_;
	gint _tmp5__length1;
	gchar* _tmp6_;
	gchar* _tmp7_;
	const gchar* _tmp8_;
	gchar* _tmp9_;
	GError* _error_;
	GError* _tmp10_;
	const gchar* _tmp11_;
	const gchar* _tmp12_;
	gchar* _tmp13_;
	const gchar* _tmp14_;
	gboolean _tmp15_;
	const gchar* _tmp16_;
	const gchar* _tmp17_;
	gchar* _tmp18_;
	const gchar* _tmp19_;
	gboolean _tmp20_;
	const gchar* _tmp21_;
	const gchar* _tmp22_;
	gchar* _tmp23_;
	const gchar* _tmp24_;
	gint _tmp25_;
	const gchar* _tmp26_;
	const gchar* _tmp27_;
	gchar* _tmp28_;
	GError * _inner_error_;
};

struct _Block65Data {
	int _ref_count_;
	GtkWidget* widget;
};

struct _BoxesCopyFileData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	GFile* src_file;
	GFile* dest_file;
	GCancellable* cancellable;
	GFile* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	GFile* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	GFile* _tmp6_;
	GFile* _tmp7_;
	GCancellable* _tmp8_;
	GFile* _tmp9_;
	gchar* _tmp10_;
	gchar* _tmp11_;
	GFile* _tmp12_;
	gchar* _tmp13_;
	gchar* _tmp14_;
	GError* _error_;
	GError * _inner_error_;
};

typedef enum  {
	BOXES_CPU_ARCH_COMPATIBILITY_INCOMPATIBLE = -1,
	BOXES_CPU_ARCH_COMPATIBILITY_IDENTICAL = 0,
	BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE = 1,
	BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE_DIFF_WORDSIZE = 2
} BoxesCPUArchCompatibility;

struct _BoxesFdotimedate1Iface {
	GTypeInterface parent_iface;
	gchar* (*get_timezone) (BoxesFdotimedate1* self);
	void (*set_timezone) (BoxesFdotimedate1* self, const gchar* value);
};


extern BoxesApp* boxes_app_app;
extern gboolean boxes_libvirt_bridge_net_checked;
gboolean boxes_libvirt_bridge_net_checked = FALSE;
extern gboolean boxes_libvirt_bridge_net_available;
gboolean boxes_libvirt_bridge_net_available = FALSE;

void boxes_gdk_rgba_to_clutter_color (GdkRGBA* gdk_rgba, ClutterColor* result);
void boxes_get_boxes_bg_color (GdkRGBA* result);
void boxes_get_color (const gchar* desc, GdkRGBA* result);
void boxes_tree_view_activate_on_single_click (GtkTreeView* tree_view, gboolean should_activate);
static Block62Data* block62_data_ref (Block62Data* _data62_);
static void block62_data_unref (void * _userdata_);
static gboolean ____lambda152_ (Block62Data* _data62_, GtkWidget* w, GdkEventButton* event);
static gboolean _____lambda152__gtk_widget_button_press_event (GtkWidget* _sender, GdkEventButton* event, gpointer self);
void boxes_icon_view_activate_on_single_click (GtkIconView* icon_view, gboolean should_activate);
static Block63Data* block63_data_ref (Block63Data* _data63_);
static void block63_data_unref (void * _userdata_);
static gboolean ____lambda234_ (Block63Data* _data63_, GtkWidget* w, GdkEventButton* event);
static gboolean _____lambda234__gtk_widget_button_release_event (GtkWidget* _sender, GdkEventButton* event, gpointer self);
gchar* boxes_extract_xpath (const gchar* xmldoc, const gchar* xpath, gboolean required, GError** error);
void boxes_allocate_actor_no_animation (ClutterActor* actor, gfloat x, gfloat y, gfloat width, gfloat height);
void boxes_fade_actor (ClutterActor* actor, guint opacity);
static Block64Data* block64_data_ref (Block64Data* _data64_);
static void block64_data_unref (void * _userdata_);
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_app_get_type (void) G_GNUC_CONST;
GType boxes_clutter_widget_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_revealer_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
GType boxes_collection_get_type (void) G_GNUC_CONST;
GType boxes_collection_filter_get_type (void) G_GNUC_CONST;
GType boxes_collection_view_get_type (void) G_GNUC_CONST;
static void __lambda136_ (Block64Data* _data64_);
static void ___lambda136__clutter_timeline_completed (ClutterTimeline* _sender, gpointer self);
ClutterTransition* boxes_animate_actor_geometry (gfloat x, gfloat y, gfloat width, gfloat height);
void boxes_actor_add (ClutterActor* actor, ClutterActor* container);
void boxes_actor_remove (ClutterActor* actor);
OsinfoDevice* boxes_find_device_by_prop (OsinfoDeviceList* devices, const gchar* prop_name, const gchar* prop_value);
GtkImage* boxes_get_os_logo (OsinfoOs* os, gint size);
void boxes_fetch_os_logo (GtkImage* image, OsinfoOs* os, gint size);
gchar* boxes_get_logo_path (OsinfoOs* os, gchar** extensions, int extensions_length1);
GVirStoragePool* boxes_get_storage_pool (GVirConnection* connection);
GVirStorageVol* boxes_get_storage_volume (GVirConnection* connection, GVirDomain* domain);
gboolean boxes_is_libvirt_bridge_net_available (void);
static void boxes_check_selinux_context_default_data_free (gpointer _data);
void boxes_check_selinux_context_default (GAsyncReadyCallback _callback_, gpointer _user_data_);
gboolean boxes_check_selinux_context_default_finish (GAsyncResult* _res_, gchar** diagnosis);
static gboolean boxes_check_selinux_context_default_co (BoxesCheckSelinuxContextDefaultData* _data_);
static void boxes_check_selinux_context_default_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_check_libvirt_kvm_data_free (gpointer _data);
void boxes_check_libvirt_kvm (GAsyncReadyCallback _callback_, gpointer _user_data_);
gboolean boxes_check_libvirt_kvm_finish (GAsyncResult* _res_);
static gboolean boxes_check_libvirt_kvm_co (BoxesCheckLibvirtKvmData* _data_);
static void boxes_check_libvirt_kvm_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_check_cpu_vt_capability_data_free (gpointer _data);
void boxes_check_cpu_vt_capability (GAsyncReadyCallback _callback_, gpointer _user_data_);
gboolean boxes_check_cpu_vt_capability_finish (GAsyncResult* _res_);
static gboolean boxes_check_cpu_vt_capability_co (BoxesCheckCpuVtCapabilityData* _data_);
static void boxes_check_cpu_vt_capability_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_check_module_kvm_loaded_data_free (gpointer _data);
void boxes_check_module_kvm_loaded (GAsyncReadyCallback _callback_, gpointer _user_data_);
gboolean boxes_check_module_kvm_loaded_finish (GAsyncResult* _res_);
static gboolean boxes_check_module_kvm_loaded_co (BoxesCheckModuleKvmLoadedData* _data_);
static void boxes_check_module_kvm_loaded_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_check_storage_pool_data_free (gpointer _data);
void boxes_check_storage_pool (GAsyncReadyCallback _callback_, gpointer _user_data_);
gboolean boxes_check_storage_pool_finish (GAsyncResult* _res_, gchar** diagnosis);
static gboolean boxes_check_storage_pool_co (BoxesCheckStoragePoolData* _data_);
static void boxes_check_storage_pool_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
GdkPixbuf* boxes_remove_alpha (GdkPixbuf* pixbuf);
static guint8* _vala_array_dup5 (guint8* self, int length);
void boxes_draw_as_css_box (GtkWidget* widget);
static Block65Data* block65_data_ref (Block65Data* _data65_);
static void block65_data_unref (void * _userdata_);
static gboolean __lambda186_ (Block65Data* _data65_, cairo_t* cr);
static gboolean ___lambda186__gtk_widget_draw (GtkWidget* _sender, cairo_t* cr, gpointer self);
static void boxes_copy_file_data_free (gpointer _data);
void boxes_copy_file (GFile* src_file, GFile* dest_file, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_copy_file_finish (GAsyncResult* _res_, GError** error);
static gboolean boxes_copy_file_co (BoxesCopyFileData* _data_);
static void boxes_copy_file_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
GType boxes_cpu_arch_compatibility_get_type (void) G_GNUC_CONST;
BoxesCPUArchCompatibility boxes_compare_cpu_architectures (const gchar* arch1, const gchar* arch2);
GType boxes_fdo_timedate1_get_type (void) G_GNUC_CONST;
GType boxes_fdo_timedate1_proxy_get_type (void) G_GNUC_CONST;
guint boxes_fdo_timedate1_register_object (void* object, GDBusConnection* connection, const gchar* path, GError** error);
gchar* boxes_fdo_timedate1_get_timezone (BoxesFdotimedate1* self);
void boxes_fdo_timedate1_set_timezone (BoxesFdotimedate1* self, const gchar* value);
static void boxes_fdo_timedate1_proxy_g_signal (GDBusProxy* proxy, const gchar* sender_name, const gchar* signal_name, GVariant* parameters);
static gchar* boxes_fdo_timedate1_dbus_proxy_get_timezone (BoxesFdotimedate1* self);
static void boxes_fdo_timedate1_dbus_proxy_set_timezone (BoxesFdotimedate1* self, const gchar* value);
static void boxes_fdo_timedate1_proxy_boxes_fdo_timedate1_interface_init (BoxesFdotimedate1Iface* iface);
static void boxes_fdo_timedate1_dbus_interface_method_call (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* method_name, GVariant* parameters, GDBusMethodInvocation* invocation, gpointer user_data);
static GVariant* boxes_fdo_timedate1_dbus_interface_get_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GError** error, gpointer user_data);
static GVariant* _dbus_boxes_fdo_timedate1_get_timezone (BoxesFdotimedate1* self);
static gboolean boxes_fdo_timedate1_dbus_interface_set_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GVariant* value, GError** error, gpointer user_data);
static void _dbus_boxes_fdo_timedate1_set_timezone (BoxesFdotimedate1* self, GVariant* _value);
static void _boxes_fdo_timedate1_unregister_object (gpointer user_data);
gchar* boxes_get_timezone (void);
gchar* boxes_get_timezone_from_systemd (GError** error);
gchar* boxes_get_timezone_from_linux (GError** error);
#define BOXES_TZ_FILE "/etc/localtime"
gboolean boxes_is_mime_type (const gchar* filename, const gchar* mime_type);
void uuid_generate (guchar* uuid);
void uuid_unparse (guchar* uuid, guchar* output);
gchar* boxes_uuid_generate (void);
GIcon* boxes_create_symbolic_emblem (const gchar* name);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
static gint _vala_array_length (gpointer array);

static GRegex* _tmp_regex_0 = NULL;
static GRegex* _tmp_regex_1 = NULL;
static const GDBusMethodInfo * const _boxes_fdo_timedate1_dbus_method_info[] = {NULL};
static const GDBusSignalInfo * const _boxes_fdo_timedate1_dbus_signal_info[] = {NULL};
static const GDBusPropertyInfo _boxes_fdo_timedate1_dbus_property_info_timezone = {-1, "Timezone", "s", G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE};
static const GDBusPropertyInfo * const _boxes_fdo_timedate1_dbus_property_info[] = {&_boxes_fdo_timedate1_dbus_property_info_timezone, NULL};
static const GDBusInterfaceInfo _boxes_fdo_timedate1_dbus_interface_info = {-1, "org.freedesktop.timedate1", (GDBusMethodInfo **) (&_boxes_fdo_timedate1_dbus_method_info), (GDBusSignalInfo **) (&_boxes_fdo_timedate1_dbus_signal_info), (GDBusPropertyInfo **) (&_boxes_fdo_timedate1_dbus_property_info)};
static const GDBusInterfaceVTable _boxes_fdo_timedate1_dbus_interface_vtable = {boxes_fdo_timedate1_dbus_interface_method_call, boxes_fdo_timedate1_dbus_interface_get_property, boxes_fdo_timedate1_dbus_interface_set_property};

void boxes_gdk_rgba_to_clutter_color (GdkRGBA* gdk_rgba, ClutterColor* result) {
	ClutterColor color = {0};
	GdkRGBA _tmp0_ = {0};
	gdouble _tmp1_ = 0.0;
	gdouble _tmp2_ = 0.0;
	GdkRGBA _tmp3_ = {0};
	gdouble _tmp4_ = 0.0;
	gdouble _tmp5_ = 0.0;
	GdkRGBA _tmp6_ = {0};
	gdouble _tmp7_ = 0.0;
	gdouble _tmp8_ = 0.0;
	GdkRGBA _tmp9_ = {0};
	gdouble _tmp10_ = 0.0;
	gdouble _tmp11_ = 0.0;
	ClutterColor _tmp12_ = {0};
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_if_fail (gdk_rgba != NULL);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = *gdk_rgba;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = _tmp0_.red;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = CLAMP (_tmp1_ * 255, (gdouble) 0, (gdouble) 255);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = *gdk_rgba;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_ = _tmp3_.green;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = CLAMP (_tmp4_ * 255, (gdouble) 0, (gdouble) 255);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp6_ = *gdk_rgba;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp7_ = _tmp6_.blue;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp8_ = CLAMP (_tmp7_ * 255, (gdouble) 0, (gdouble) 255);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp9_ = *gdk_rgba;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp10_ = _tmp9_.alpha;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp11_ = CLAMP (_tmp10_ * 255, (gdouble) 0, (gdouble) 255);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp12_.red = (guint8) _tmp2_;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp12_.green = (guint8) _tmp5_;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp12_.blue = (guint8) _tmp8_;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp12_.alpha = (guint8) _tmp11_;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	color = _tmp12_;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	*result = color;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return;
#line 717 "util-app.c"
}


void boxes_get_boxes_bg_color (GdkRGBA* result) {
	GtkStyleContext* style = NULL;
	GtkStyleContext* _tmp0_ = NULL;
	GtkWidgetPath* path = NULL;
	GtkWidgetPath* _tmp1_ = NULL;
	GdkRGBA _tmp2_ = {0};
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = gtk_style_context_new ();
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	style = _tmp0_;
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = gtk_widget_path_new ();
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	path = _tmp1_;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	gtk_widget_path_append_type (path, GTK_TYPE_WINDOW);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	gtk_style_context_set_path (style, path);
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	gtk_style_context_add_class (style, "boxes-bg");
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	gtk_style_context_get_background_color (style, 0, &_tmp2_);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	*result = _tmp2_;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_gtk_widget_path_unref0 (path);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (style);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return;
#line 751 "util-app.c"
}


void boxes_get_color (const gchar* desc, GdkRGBA* result) {
	GdkRGBA color = {0};
	const gchar* _tmp0_ = NULL;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_if_fail (desc != NULL);
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	memset (&color, 0, sizeof (GdkRGBA));
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = desc;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	gdk_rgba_parse (&color, _tmp0_);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	*result = color;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return;
#line 770 "util-app.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return self ? g_object_ref (self) : NULL;
#line 777 "util-app.c"
}


static Block62Data* block62_data_ref (Block62Data* _data62_) {
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_atomic_int_inc (&_data62_->_ref_count_);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return _data62_;
#line 786 "util-app.c"
}


static void block62_data_unref (void * _userdata_) {
	Block62Data* _data62_;
	_data62_ = (Block62Data*) _userdata_;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (g_atomic_int_dec_and_test (&_data62_->_ref_count_)) {
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (_data62_->tree_view);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_slice_free (Block62Data, _data62_);
#line 799 "util-app.c"
	}
}


static gboolean ____lambda152_ (Block62Data* _data62_, GtkWidget* w, GdkEventButton* event) {
	gboolean result = FALSE;
	GtkTreePath* path = NULL;
	GtkTreeViewColumn* column = NULL;
	gint x = 0;
	gint y = 0;
	gboolean _tmp0_ = FALSE;
	GdkEventButton _tmp1_ = {0};
	guint _tmp2_ = 0U;
	gboolean _tmp5_ = FALSE;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (w != NULL, FALSE);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = *event;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = _tmp1_.button;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp2_ == ((guint) 1)) {
#line 824 "util-app.c"
		GdkEventButton _tmp3_ = {0};
		GdkEventType _tmp4_ = 0;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp3_ = *event;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp4_ = _tmp3_.type;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp0_ = _tmp4_ == GDK_BUTTON_PRESS;
#line 833 "util-app.c"
	} else {
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp0_ = FALSE;
#line 837 "util-app.c"
	}
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = _tmp0_;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp5_) {
#line 843 "util-app.c"
		GtkTreeView* _tmp6_ = NULL;
		GdkEventButton _tmp7_ = {0};
		gdouble _tmp8_ = 0.0;
		GdkEventButton _tmp9_ = {0};
		gdouble _tmp10_ = 0.0;
		GtkTreePath* _tmp11_ = NULL;
		GtkTreeViewColumn* _tmp12_ = NULL;
		gint _tmp13_ = 0;
		gint _tmp14_ = 0;
		GtkTreePath* _tmp15_ = NULL;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp6_ = _data62_->tree_view;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp7_ = *event;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp8_ = _tmp7_.x;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp9_ = *event;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp10_ = _tmp9_.y;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		gtk_tree_view_get_path_at_pos (_tmp6_, (gint) _tmp8_, (gint) _tmp10_, &_tmp11_, &_tmp12_, &_tmp13_, &_tmp14_);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_gtk_tree_path_free0 (path);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		path = _tmp11_;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		column = _tmp12_;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		x = _tmp13_;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		y = _tmp14_;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp15_ = path;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_tmp15_ != NULL) {
#line 880 "util-app.c"
			GtkTreeView* _tmp16_ = NULL;
			GtkTreePath* _tmp17_ = NULL;
			GtkTreeViewColumn* _tmp18_ = NULL;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp16_ = _data62_->tree_view;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp17_ = path;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp18_ = column;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			gtk_tree_view_row_activated (_tmp16_, _tmp17_, _tmp18_);
#line 892 "util-app.c"
		}
	}
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = FALSE;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_gtk_tree_path_free0 (path);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 901 "util-app.c"
}


static gboolean _____lambda152__gtk_widget_button_press_event (GtkWidget* _sender, GdkEventButton* event, gpointer self) {
	gboolean result;
	result = ____lambda152_ (self, _sender, event);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 910 "util-app.c"
}


void boxes_tree_view_activate_on_single_click (GtkTreeView* tree_view, gboolean should_activate) {
	Block62Data* _data62_;
	GtkTreeView* _tmp0_ = NULL;
	GtkTreeView* _tmp1_ = NULL;
	gulong id = 0UL;
	GtkTreeView* _tmp2_ = NULL;
	gconstpointer _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	gulong _tmp5_ = 0UL;
	gboolean _tmp7_ = FALSE;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_if_fail (tree_view != NULL);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data62_ = g_slice_new0 (Block62Data);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data62_->_ref_count_ = 1;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = tree_view;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (_data62_->tree_view);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data62_->tree_view = _tmp1_;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = _data62_->tree_view;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = g_object_get_data ((GObject*) _tmp2_, "boxes-tree-view-activate");
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	id = (gulong) ((guintptr) _tmp3_);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = id;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp5_ != ((gulong) 0)) {
#line 948 "util-app.c"
		gboolean _tmp6_ = FALSE;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp6_ = should_activate;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp4_ = _tmp6_ == FALSE;
#line 954 "util-app.c"
	} else {
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp4_ = FALSE;
#line 958 "util-app.c"
	}
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp7_ = _tmp4_;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp7_) {
#line 964 "util-app.c"
		GtkTreeView* _tmp8_ = NULL;
		gulong _tmp9_ = 0UL;
		GtkTreeView* _tmp10_ = NULL;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp8_ = _data62_->tree_view;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp9_ = id;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_signal_handler_disconnect ((GObject*) _tmp8_, _tmp9_);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp10_ = _data62_->tree_view;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_object_set_data_full ((GObject*) _tmp10_, "boxes-tree-view-activate", (gpointer) ((guintptr) ((gulong) 0)), NULL);
#line 978 "util-app.c"
	} else {
		gboolean _tmp11_ = FALSE;
		gulong _tmp12_ = 0UL;
		gboolean _tmp14_ = FALSE;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp12_ = id;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_tmp12_ == ((gulong) 0)) {
#line 987 "util-app.c"
			gboolean _tmp13_ = FALSE;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp13_ = should_activate;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp11_ = _tmp13_;
#line 993 "util-app.c"
		} else {
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp11_ = FALSE;
#line 997 "util-app.c"
		}
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp14_ = _tmp11_;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_tmp14_) {
#line 1003 "util-app.c"
			GtkTreeView* _tmp15_ = NULL;
			gulong _tmp16_ = 0UL;
			GtkTreeView* _tmp17_ = NULL;
			gulong _tmp18_ = 0UL;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp15_ = _data62_->tree_view;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp16_ = g_signal_connect_data ((GtkWidget*) _tmp15_, "button-press-event", (GCallback) _____lambda152__gtk_widget_button_press_event, block62_data_ref (_data62_), (GClosureNotify) block62_data_unref, 0);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			id = _tmp16_;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp17_ = _data62_->tree_view;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp18_ = id;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_object_set_data_full ((GObject*) _tmp17_, "boxes-tree-view-activate", (gpointer) ((guintptr) _tmp18_), NULL);
#line 1020 "util-app.c"
		}
	}
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	block62_data_unref (_data62_);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data62_ = NULL;
#line 1027 "util-app.c"
}


static Block63Data* block63_data_ref (Block63Data* _data63_) {
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_atomic_int_inc (&_data63_->_ref_count_);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return _data63_;
#line 1036 "util-app.c"
}


static void block63_data_unref (void * _userdata_) {
	Block63Data* _data63_;
	_data63_ = (Block63Data*) _userdata_;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (g_atomic_int_dec_and_test (&_data63_->_ref_count_)) {
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (_data63_->icon_view);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_slice_free (Block63Data, _data63_);
#line 1049 "util-app.c"
	}
}


static gpointer _gtk_tree_path_copy0 (gpointer self) {
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return self ? gtk_tree_path_copy (self) : NULL;
#line 1057 "util-app.c"
}


static gboolean ____lambda234_ (Block63Data* _data63_, GtkWidget* w, GdkEventButton* event) {
	gboolean result = FALSE;
	GtkTreePath* path = NULL;
	GdkEventButton _tmp0_ = {0};
	guint _tmp1_ = 0U;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (w != NULL, FALSE);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = *event;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = _tmp0_.button;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp1_ == ((guint) 1)) {
#line 1076 "util-app.c"
		GtkIconView* _tmp2_ = NULL;
		GdkEventButton _tmp3_ = {0};
		gdouble _tmp4_ = 0.0;
		GdkEventButton _tmp5_ = {0};
		gdouble _tmp6_ = 0.0;
		GtkTreePath* _tmp7_ = NULL;
		GtkTreePath* _tmp8_ = NULL;
		GtkTreePath* _tmp9_ = NULL;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp2_ = _data63_->icon_view;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp3_ = *event;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp4_ = _tmp3_.x;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp5_ = *event;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp6_ = _tmp5_.y;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp7_ = gtk_icon_view_get_path_at_pos (_tmp2_, (gint) _tmp4_, (gint) _tmp6_);
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp8_ = _gtk_tree_path_copy0 (_tmp7_);
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_gtk_tree_path_free0 (path);
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		path = _tmp8_;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp9_ = path;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_tmp9_ != NULL) {
#line 1107 "util-app.c"
			GtkIconView* _tmp10_ = NULL;
			GtkTreePath* _tmp11_ = NULL;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp10_ = _data63_->icon_view;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp11_ = path;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			gtk_icon_view_item_activated (_tmp10_, _tmp11_);
#line 1116 "util-app.c"
		}
	}
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = FALSE;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_gtk_tree_path_free0 (path);
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 1125 "util-app.c"
}


static gboolean _____lambda234__gtk_widget_button_release_event (GtkWidget* _sender, GdkEventButton* event, gpointer self) {
	gboolean result;
	result = ____lambda234_ (self, _sender, event);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 1134 "util-app.c"
}


void boxes_icon_view_activate_on_single_click (GtkIconView* icon_view, gboolean should_activate) {
	Block63Data* _data63_;
	GtkIconView* _tmp0_ = NULL;
	GtkIconView* _tmp1_ = NULL;
	gulong id = 0UL;
	GtkIconView* _tmp2_ = NULL;
	gconstpointer _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	gulong _tmp5_ = 0UL;
	gboolean _tmp7_ = FALSE;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_if_fail (icon_view != NULL);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data63_ = g_slice_new0 (Block63Data);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data63_->_ref_count_ = 1;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = icon_view;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (_data63_->icon_view);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data63_->icon_view = _tmp1_;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = _data63_->icon_view;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = g_object_get_data ((GObject*) _tmp2_, "boxes-icon-view-activate");
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	id = (gulong) ((guintptr) _tmp3_);
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = id;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp5_ != ((gulong) 0)) {
#line 1172 "util-app.c"
		gboolean _tmp6_ = FALSE;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp6_ = should_activate;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp4_ = _tmp6_ == FALSE;
#line 1178 "util-app.c"
	} else {
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp4_ = FALSE;
#line 1182 "util-app.c"
	}
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp7_ = _tmp4_;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp7_) {
#line 1188 "util-app.c"
		GtkIconView* _tmp8_ = NULL;
		gulong _tmp9_ = 0UL;
		GtkIconView* _tmp10_ = NULL;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp8_ = _data63_->icon_view;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp9_ = id;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_signal_handler_disconnect ((GObject*) _tmp8_, _tmp9_);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp10_ = _data63_->icon_view;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_object_set_data_full ((GObject*) _tmp10_, "boxes-icon-view-activate", (gpointer) ((guintptr) ((gulong) 0)), NULL);
#line 1202 "util-app.c"
	} else {
		gboolean _tmp11_ = FALSE;
		gulong _tmp12_ = 0UL;
		gboolean _tmp14_ = FALSE;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp12_ = id;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_tmp12_ == ((gulong) 0)) {
#line 1211 "util-app.c"
			gboolean _tmp13_ = FALSE;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp13_ = should_activate;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp11_ = _tmp13_;
#line 1217 "util-app.c"
		} else {
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp11_ = FALSE;
#line 1221 "util-app.c"
		}
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp14_ = _tmp11_;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_tmp14_) {
#line 1227 "util-app.c"
			GtkIconView* _tmp15_ = NULL;
			gulong _tmp16_ = 0UL;
			GtkIconView* _tmp17_ = NULL;
			gulong _tmp18_ = 0UL;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp15_ = _data63_->icon_view;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp16_ = g_signal_connect_data ((GtkWidget*) _tmp15_, "button-release-event", (GCallback) _____lambda234__gtk_widget_button_release_event, block63_data_ref (_data63_), (GClosureNotify) block63_data_unref, 0);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			id = _tmp16_;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp17_ = _data63_->icon_view;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp18_ = id;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_object_set_data_full ((GObject*) _tmp17_, "boxes-icon-view-activate", (gpointer) ((guintptr) _tmp18_), NULL);
#line 1244 "util-app.c"
		}
	}
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	block63_data_unref (_data63_);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data63_ = NULL;
#line 1251 "util-app.c"
}


gchar* boxes_extract_xpath (const gchar* xmldoc, const gchar* xpath, gboolean required, GError** error) {
	gchar* result = NULL;
	xmlParserCtxt* parser = NULL;
	xmlParserCtxt* _tmp0_ = NULL;
	xmlDoc* doc = NULL;
	xmlParserCtxt* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	xmlDoc* _tmp3_ = NULL;
	xmlDoc* _tmp4_ = NULL;
	xmlXPathContext* ctxt = NULL;
	xmlDoc* _tmp6_ = NULL;
	xmlXPathContext* _tmp7_ = NULL;
	xmlXPathObject* obj = NULL;
	xmlXPathContext* _tmp8_ = NULL;
	const gchar* _tmp9_ = NULL;
	xmlXPathObject* _tmp10_ = NULL;
	gboolean _tmp11_ = FALSE;
	xmlXPathObject* _tmp12_ = NULL;
	gboolean _tmp15_ = FALSE;
	xmlXPathObject* _tmp22_ = NULL;
	xmlXPathObjectType _tmp23_ = 0;
	xmlXPathObject* _tmp29_ = NULL;
	const gchar* _tmp30_ = NULL;
	gchar* _tmp31_ = NULL;
	GError * _inner_error_ = NULL;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (xmldoc != NULL, NULL);
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (xpath != NULL, NULL);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = xmlNewParserCtxt ();
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	parser = _tmp0_;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = parser;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = xmldoc;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = xmlCtxtReadDoc (_tmp1_, (xmlChar*) _tmp2_, "doc.xml", NULL, 0);
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	doc = _tmp3_;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_ = doc;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp4_ == NULL) {
#line 1300 "util-app.c"
		GError* _tmp5_ = NULL;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp5_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, "Can't parse XML doc");
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_inner_error_ = _tmp5_;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_inner_error_->domain == BOXES_ERROR) {
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_propagate_error (error, _inner_error_);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_xmlFreeParserCtxt0 (parser);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			return NULL;
#line 1314 "util-app.c"
		} else {
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_xmlFreeParserCtxt0 (parser);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_clear_error (&_inner_error_);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			return NULL;
#line 1324 "util-app.c"
		}
	}
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp6_ = doc;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp7_ = xmlXPathNewContext (_tmp6_);
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	ctxt = _tmp7_;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp8_ = ctxt;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp9_ = xpath;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp10_ = xmlXPathEval ((xmlChar*) _tmp9_, _tmp8_);
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	obj = _tmp10_;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp12_ = obj;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp12_ == NULL) {
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp11_ = TRUE;
#line 1347 "util-app.c"
	} else {
		xmlXPathObject* _tmp13_ = NULL;
		const gchar* _tmp14_ = NULL;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp13_ = obj;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp14_ = _tmp13_->stringval;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp11_ = _tmp14_ == NULL;
#line 1357 "util-app.c"
	}
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp15_ = _tmp11_;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp15_) {
#line 1363 "util-app.c"
		gboolean _tmp16_ = FALSE;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp16_ = required;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_tmp16_) {
#line 1369 "util-app.c"
			const gchar* _tmp17_ = NULL;
			gchar* _tmp18_ = NULL;
			gchar* _tmp19_ = NULL;
			GError* _tmp20_ = NULL;
			GError* _tmp21_ = NULL;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp17_ = xpath;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp18_ = g_strconcat ("Failed to extract xpath ", _tmp17_, NULL);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp19_ = _tmp18_;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp20_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _tmp19_);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp21_ = _tmp20_;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (_tmp19_);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_inner_error_ = _tmp21_;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (_inner_error_->domain == BOXES_ERROR) {
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				g_propagate_error (error, _inner_error_);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_xmlXPathFreeContext0 (ctxt);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_xmlFreeParserCtxt0 (parser);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				return NULL;
#line 1399 "util-app.c"
			} else {
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_xmlXPathFreeContext0 (ctxt);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_xmlFreeParserCtxt0 (parser);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				g_clear_error (&_inner_error_);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				return NULL;
#line 1411 "util-app.c"
			}
		} else {
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			result = NULL;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_xmlXPathFreeContext0 (ctxt);
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_xmlFreeParserCtxt0 (parser);
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			return result;
#line 1422 "util-app.c"
		}
	}
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp22_ = obj;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp23_ = _tmp22_->type;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp23_ != XPATH_STRING) {
#line 1431 "util-app.c"
		const gchar* _tmp24_ = NULL;
		gchar* _tmp25_ = NULL;
		gchar* _tmp26_ = NULL;
		GError* _tmp27_ = NULL;
		GError* _tmp28_ = NULL;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp24_ = xpath;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp25_ = g_strconcat ("Failed to extract xpath ", _tmp24_, NULL);
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp26_ = _tmp25_;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp27_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _tmp26_);
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp28_ = _tmp27_;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_tmp26_);
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_inner_error_ = _tmp28_;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_inner_error_->domain == BOXES_ERROR) {
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_propagate_error (error, _inner_error_);
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_xmlXPathFreeContext0 (ctxt);
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_xmlFreeParserCtxt0 (parser);
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			return NULL;
#line 1461 "util-app.c"
		} else {
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_xmlXPathFreeContext0 (ctxt);
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_xmlFreeParserCtxt0 (parser);
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_clear_error (&_inner_error_);
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			return NULL;
#line 1473 "util-app.c"
		}
	}
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp29_ = obj;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp30_ = _tmp29_->stringval;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp31_ = g_strdup (_tmp30_);
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = _tmp31_;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_xmlXPathFreeContext0 (ctxt);
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_xmlFreeParserCtxt0 (parser);
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 1490 "util-app.c"
}


void boxes_allocate_actor_no_animation (ClutterActor* actor, gfloat x, gfloat y, gfloat width, gfloat height) {
	guint old_duration = 0U;
	ClutterActor* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	ClutterActor* _tmp2_ = NULL;
	ClutterActorBox box = {0};
	gfloat _tmp3_ = 0.0F;
	gfloat _tmp4_ = 0.0F;
	gfloat _tmp5_ = 0.0F;
	gfloat _tmp6_ = 0.0F;
	gfloat _tmp7_ = 0.0F;
	gfloat _tmp8_ = 0.0F;
	ClutterActorBox _tmp9_ = {0};
	ClutterActor* _tmp10_ = NULL;
	ClutterActorBox _tmp11_ = {0};
	ClutterActor* _tmp12_ = NULL;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_if_fail (actor != NULL);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = actor;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = clutter_actor_get_easing_duration (_tmp0_);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	old_duration = _tmp1_;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = actor;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	clutter_actor_set_easing_duration (_tmp2_, (guint) 0);
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = x;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_ = y;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = x;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp6_ = width;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp7_ = y;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp8_ = height;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp9_.x1 = _tmp3_;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp9_.y1 = _tmp4_;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp9_.x2 = _tmp5_ + _tmp6_;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp9_.y2 = _tmp7_ + _tmp8_;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	box = _tmp9_;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp10_ = actor;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp11_ = box;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	clutter_actor_allocate (_tmp10_, &_tmp11_, 0);
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp12_ = actor;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	clutter_actor_set_easing_duration (_tmp12_, old_duration);
#line 1554 "util-app.c"
}


static Block64Data* block64_data_ref (Block64Data* _data64_) {
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_atomic_int_inc (&_data64_->_ref_count_);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return _data64_;
#line 1563 "util-app.c"
}


static void block64_data_unref (void * _userdata_) {
	Block64Data* _data64_;
	_data64_ = (Block64Data*) _userdata_;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (g_atomic_int_dec_and_test (&_data64_->_ref_count_)) {
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (_data64_->actor);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_slice_free (Block64Data, _data64_);
#line 1576 "util-app.c"
	}
}


static void __lambda136_ (Block64Data* _data64_) {
	ClutterActor* _tmp0_ = NULL;
	ClutterActor* _tmp1_ = NULL;
	ClutterActor* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	guint _tmp4_ = 0U;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = _data64_->actor;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	clutter_actor_remove_transition (_tmp0_, "animate-opacity");
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = _data64_->actor;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = _data64_->actor;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = clutter_actor_get_opacity (_tmp2_);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_ = _tmp3_;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_set (_tmp1_, "visible", _tmp4_ != ((guint) 0), NULL);
#line 1601 "util-app.c"
}


static void ___lambda136__clutter_timeline_completed (ClutterTimeline* _sender, gpointer self) {
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	__lambda136_ (self);
#line 1608 "util-app.c"
}


void boxes_fade_actor (ClutterActor* actor, guint opacity) {
	Block64Data* _data64_;
	ClutterActor* _tmp0_ = NULL;
	ClutterActor* _tmp1_ = NULL;
	guint _tmp2_ = 0U;
	ClutterActor* _tmp4_ = NULL;
	guint _tmp5_ = 0U;
	ClutterTransition* transition = NULL;
	ClutterActor* _tmp6_ = NULL;
	ClutterTransition* _tmp7_ = NULL;
	ClutterTransition* _tmp8_ = NULL;
	ClutterTransition* _tmp9_ = NULL;
	ClutterPropertyTransition* _tmp11_ = NULL;
	GValue value = {0};
	GValue _tmp12_ = {0};
	guint _tmp13_ = 0U;
	ClutterTransition* _tmp14_ = NULL;
	GValue _tmp15_ = {0};
	ClutterTransition* _tmp16_ = NULL;
	BoxesApp* _tmp17_ = NULL;
	guint _tmp18_ = 0U;
	ClutterTransition* _tmp19_ = NULL;
	ClutterTransition* _tmp20_ = NULL;
	ClutterActor* _tmp21_ = NULL;
	ClutterTransition* _tmp22_ = NULL;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_if_fail (actor != NULL);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data64_ = g_slice_new0 (Block64Data);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data64_->_ref_count_ = 1;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = actor;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (_data64_->actor);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data64_->actor = _tmp1_;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = opacity;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp2_ != ((guint) 0)) {
#line 1655 "util-app.c"
		ClutterActor* _tmp3_ = NULL;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp3_ = _data64_->actor;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		clutter_actor_show (_tmp3_);
#line 1661 "util-app.c"
	}
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_ = _data64_->actor;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = opacity;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	clutter_actor_set_reactive (_tmp4_, _tmp5_ == ((guint) 255));
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp6_ = _data64_->actor;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp7_ = clutter_actor_get_transition (_tmp6_, "animate-opacity");
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp8_ = _g_object_ref0 (_tmp7_);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	transition = _tmp8_;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp9_ = transition;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp9_ != NULL) {
#line 1681 "util-app.c"
		ClutterActor* _tmp10_ = NULL;
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp10_ = _data64_->actor;
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		clutter_actor_remove_transition (_tmp10_, "animate-opacity");
#line 1687 "util-app.c"
	}
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp11_ = (ClutterPropertyTransition*) clutter_property_transition_new ("opacity");
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (transition);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	transition = (ClutterTransition*) _tmp11_;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_value_init (&_tmp12_, G_TYPE_UINT);
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	value = _tmp12_;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp13_ = opacity;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_value_set_uint (&value, _tmp13_);
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp14_ = transition;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp15_ = value;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	clutter_transition_set_to_value (_tmp14_, &_tmp15_);
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp16_ = transition;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp17_ = boxes_app_app;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp18_ = _tmp17_->duration;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	clutter_timeline_set_duration ((ClutterTimeline*) _tmp16_, _tmp18_);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp19_ = transition;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	clutter_timeline_set_progress_mode ((ClutterTimeline*) _tmp19_, CLUTTER_EASE_OUT_QUAD);
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp20_ = transition;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_signal_connect_data ((ClutterTimeline*) _tmp20_, "completed", (GCallback) ___lambda136__clutter_timeline_completed, block64_data_ref (_data64_), (GClosureNotify) block64_data_unref, 0);
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp21_ = _data64_->actor;
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp22_ = transition;
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	clutter_actor_add_transition (_tmp21_, "animate-opacity", _tmp22_);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	G_IS_VALUE (&value) ? (g_value_unset (&value), NULL) : NULL;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (transition);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	block64_data_unref (_data64_);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data64_ = NULL;
#line 1739 "util-app.c"
}


ClutterTransition* boxes_animate_actor_geometry (gfloat x, gfloat y, gfloat width, gfloat height) {
	ClutterTransition* result = NULL;
	ClutterTransitionGroup* transition = NULL;
	ClutterTransitionGroup* _tmp0_ = NULL;
	ClutterTransitionGroup* _tmp1_ = NULL;
	BoxesApp* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	ClutterTransitionGroup* _tmp4_ = NULL;
	GValue value = {0};
	GValue _tmp5_ = {0};
	gfloat _tmp6_ = 0.0F;
	gfloat _tmp13_ = 0.0F;
	gfloat _tmp20_ = 0.0F;
	gfloat _tmp27_ = 0.0F;
	ClutterTransitionGroup* _tmp34_ = NULL;
	ClutterTransition* _tmp35_ = NULL;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = (ClutterTransitionGroup*) clutter_transition_group_new ();
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	transition = _tmp0_;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = transition;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = boxes_app_app;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = _tmp2_->duration;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	clutter_timeline_set_duration ((ClutterTimeline*) _tmp1_, _tmp3_);
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_ = transition;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	clutter_timeline_set_progress_mode ((ClutterTimeline*) _tmp4_, CLUTTER_EASE_OUT_QUAD);
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_value_init (&_tmp5_, G_TYPE_FLOAT);
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	value = _tmp5_;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp6_ = x;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp6_ > ((gfloat) 0)) {
#line 1783 "util-app.c"
		ClutterPropertyTransition* x_transition = NULL;
		ClutterPropertyTransition* _tmp7_ = NULL;
		gfloat _tmp8_ = 0.0F;
		ClutterPropertyTransition* _tmp9_ = NULL;
		GValue _tmp10_ = {0};
		ClutterTransitionGroup* _tmp11_ = NULL;
		ClutterPropertyTransition* _tmp12_ = NULL;
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp7_ = (ClutterPropertyTransition*) clutter_property_transition_new ("x");
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		x_transition = _tmp7_;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp8_ = x;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_value_set_float (&value, _tmp8_);
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp9_ = x_transition;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp10_ = value;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		clutter_transition_set_to_value ((ClutterTransition*) _tmp9_, &_tmp10_);
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp11_ = transition;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp12_ = x_transition;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		clutter_transition_group_add_transition (_tmp11_, (ClutterTransition*) _tmp12_);
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (x_transition);
#line 1813 "util-app.c"
	}
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp13_ = y;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp13_ > ((gfloat) 0)) {
#line 1819 "util-app.c"
		ClutterPropertyTransition* y_transition = NULL;
		ClutterPropertyTransition* _tmp14_ = NULL;
		gfloat _tmp15_ = 0.0F;
		ClutterTransitionGroup* _tmp16_ = NULL;
		GValue _tmp17_ = {0};
		ClutterTransitionGroup* _tmp18_ = NULL;
		ClutterPropertyTransition* _tmp19_ = NULL;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp14_ = (ClutterPropertyTransition*) clutter_property_transition_new ("y");
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		y_transition = _tmp14_;
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp15_ = y;
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_value_set_float (&value, _tmp15_);
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp16_ = transition;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp17_ = value;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		clutter_transition_set_to_value ((ClutterTransition*) _tmp16_, &_tmp17_);
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp18_ = transition;
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp19_ = y_transition;
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		clutter_transition_group_add_transition (_tmp18_, (ClutterTransition*) _tmp19_);
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (y_transition);
#line 1849 "util-app.c"
	}
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp20_ = width;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp20_ > ((gfloat) 0)) {
#line 1855 "util-app.c"
		ClutterPropertyTransition* width_transition = NULL;
		ClutterPropertyTransition* _tmp21_ = NULL;
		gfloat _tmp22_ = 0.0F;
		ClutterTransitionGroup* _tmp23_ = NULL;
		GValue _tmp24_ = {0};
		ClutterTransitionGroup* _tmp25_ = NULL;
		ClutterPropertyTransition* _tmp26_ = NULL;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp21_ = (ClutterPropertyTransition*) clutter_property_transition_new ("width");
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		width_transition = _tmp21_;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp22_ = width;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_value_set_float (&value, _tmp22_);
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp23_ = transition;
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp24_ = value;
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		clutter_transition_set_to_value ((ClutterTransition*) _tmp23_, &_tmp24_);
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp25_ = transition;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp26_ = width_transition;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		clutter_transition_group_add_transition (_tmp25_, (ClutterTransition*) _tmp26_);
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (width_transition);
#line 1885 "util-app.c"
	}
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp27_ = height;
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp27_ > ((gfloat) 0)) {
#line 1891 "util-app.c"
		ClutterPropertyTransition* height_transition = NULL;
		ClutterPropertyTransition* _tmp28_ = NULL;
		gfloat _tmp29_ = 0.0F;
		ClutterTransitionGroup* _tmp30_ = NULL;
		GValue _tmp31_ = {0};
		ClutterTransitionGroup* _tmp32_ = NULL;
		ClutterPropertyTransition* _tmp33_ = NULL;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp28_ = (ClutterPropertyTransition*) clutter_property_transition_new ("height");
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		height_transition = _tmp28_;
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp29_ = height;
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_value_set_float (&value, _tmp29_);
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp30_ = transition;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp31_ = value;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		clutter_transition_set_to_value ((ClutterTransition*) _tmp30_, &_tmp31_);
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp32_ = transition;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp33_ = height_transition;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		clutter_transition_group_add_transition (_tmp32_, (ClutterTransition*) _tmp33_);
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (height_transition);
#line 1921 "util-app.c"
	}
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp34_ = transition;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp35_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp34_, clutter_transition_get_type ()) ? ((ClutterTransition*) _tmp34_) : NULL);
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = _tmp35_;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	G_IS_VALUE (&value) ? (g_value_unset (&value), NULL) : NULL;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (transition);
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 1935 "util-app.c"
}


void boxes_actor_add (ClutterActor* actor, ClutterActor* container) {
	ClutterActor* _tmp0_ = NULL;
	ClutterActor* _tmp1_ = NULL;
	ClutterActor* _tmp2_ = NULL;
	ClutterActor* _tmp3_ = NULL;
	ClutterActor* _tmp4_ = NULL;
	ClutterActor* _tmp5_ = NULL;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_if_fail (actor != NULL);
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_if_fail (container != NULL);
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = actor;
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = clutter_actor_get_parent (_tmp0_);
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = container;
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp1_ == _tmp2_) {
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return;
#line 1960 "util-app.c"
	}
#line 180 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = actor;
#line 180 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	boxes_actor_remove (_tmp3_);
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_ = container;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = actor;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	clutter_actor_add_child (_tmp4_, _tmp5_);
#line 1972 "util-app.c"
}


void boxes_actor_remove (ClutterActor* actor) {
	ClutterActor* container = NULL;
	ClutterActor* _tmp0_ = NULL;
	ClutterActor* _tmp1_ = NULL;
	ClutterActor* _tmp2_ = NULL;
	ClutterActor* _tmp3_ = NULL;
	ClutterActor* _tmp4_ = NULL;
	ClutterActor* _tmp5_ = NULL;
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_if_fail (actor != NULL);
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = actor;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = clutter_actor_get_parent (_tmp0_);
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	container = _tmp2_;
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = container;
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp3_ == NULL) {
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (container);
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return;
#line 2002 "util-app.c"
	}
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_ = container;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = actor;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	clutter_actor_remove_child (_tmp4_, _tmp5_);
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (container);
#line 2012 "util-app.c"
}


OsinfoDevice* boxes_find_device_by_prop (OsinfoDeviceList* devices, const gchar* prop_name, const gchar* prop_value) {
	OsinfoDevice* result = NULL;
	OsinfoFilter* filter = NULL;
	OsinfoFilter* _tmp0_ = NULL;
	OsinfoFilter* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	OsinfoList* filtered = NULL;
	OsinfoDeviceList* _tmp4_ = NULL;
	OsinfoFilter* _tmp5_ = NULL;
	OsinfoList* _tmp6_ = NULL;
	OsinfoList* _tmp7_ = NULL;
	gint _tmp8_ = 0;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (devices != NULL, NULL);
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (prop_name != NULL, NULL);
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (prop_value != NULL, NULL);
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = osinfo_filter_new ();
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	filter = _tmp0_;
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = filter;
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = prop_name;
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = prop_value;
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	osinfo_filter_add_constraint (_tmp1_, _tmp2_, _tmp3_);
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_ = devices;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = filter;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp6_ = osinfo_list_new_filtered (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, osinfo_list_get_type ()) ? ((OsinfoList*) _tmp4_) : NULL, _tmp5_);
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	filtered = _tmp6_;
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp7_ = filtered;
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp8_ = osinfo_list_get_length (_tmp7_);
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp8_ > 0) {
#line 2061 "util-app.c"
		OsinfoList* _tmp9_ = NULL;
		OsinfoEntity* _tmp10_ = NULL;
		OsinfoDevice* _tmp11_ = NULL;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp9_ = filtered;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp10_ = osinfo_list_get_nth (_tmp9_, 0);
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp11_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp10_, osinfo_device_get_type ()) ? ((OsinfoDevice*) _tmp10_) : NULL);
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		result = _tmp11_;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (filtered);
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (filter);
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return result;
#line 2079 "util-app.c"
	} else {
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		result = NULL;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (filtered);
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (filter);
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return result;
#line 2089 "util-app.c"
	}
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (filtered);
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (filter);
#line 2095 "util-app.c"
}


GtkImage* boxes_get_os_logo (OsinfoOs* os, gint size) {
	GtkImage* result = NULL;
	GtkImage* image = NULL;
	GtkImage* _tmp0_ = NULL;
	GtkImage* _tmp1_ = NULL;
	gint _tmp2_ = 0;
	OsinfoOs* _tmp3_ = NULL;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = (GtkImage*) gtk_image_new_from_icon_name ("media-optical", 0);
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_ref_sink (_tmp0_);
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	image = _tmp0_;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = image;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = size;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	gtk_image_set_pixel_size (_tmp1_, _tmp2_);
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = os;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp3_ != NULL) {
#line 2122 "util-app.c"
		GtkImage* _tmp4_ = NULL;
		OsinfoOs* _tmp5_ = NULL;
		gint _tmp6_ = 0;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp4_ = image;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp5_ = os;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp6_ = size;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		boxes_fetch_os_logo (_tmp4_, _tmp5_, _tmp6_);
#line 2134 "util-app.c"
	}
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = image;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 2140 "util-app.c"
}


void boxes_fetch_os_logo (GtkImage* image, OsinfoOs* os, gint size) {
	gchar* path = NULL;
	OsinfoOs* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar** _tmp4_ = NULL;
	gchar** _tmp5_ = NULL;
	gint _tmp5__length1 = 0;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	GError * _inner_error_ = NULL;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_if_fail (image != NULL);
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_if_fail (os != NULL);
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = os;
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = g_strdup (".svg");
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = g_strdup (".png");
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = g_strdup (".jpg");
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_ = g_new0 (gchar*, 3 + 1);
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_[0] = _tmp1_;
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_[1] = _tmp2_;
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_[2] = _tmp3_;
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = _tmp4_;
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5__length1 = 3;
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp6_ = boxes_get_logo_path (_tmp0_, _tmp5_, 3);
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp7_ = _tmp6_;
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = (_vala_array_free (_tmp5_, _tmp5__length1, (GDestroyNotify) g_free), NULL);
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	path = _tmp7_;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp8_ = path;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp8_ == NULL) {
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (path);
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return;
#line 2197 "util-app.c"
	}
	{
		GdkPixbuf* pixbuf = NULL;
		const gchar* _tmp9_ = NULL;
		gint _tmp10_ = 0;
		GdkPixbuf* _tmp11_ = NULL;
		GtkImage* _tmp12_ = NULL;
		GdkPixbuf* _tmp13_ = NULL;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp9_ = path;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp10_ = size;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp11_ = gdk_pixbuf_new_from_file_at_size (_tmp9_, _tmp10_, -1, &_inner_error_);
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		pixbuf = _tmp11_;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_inner_error_ != NULL) {
#line 2216 "util-app.c"
			goto __catch84_g_error;
		}
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp12_ = image;
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp13_ = pixbuf;
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		gtk_image_set_from_pixbuf (_tmp12_, _tmp13_);
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (pixbuf);
#line 2227 "util-app.c"
	}
	goto __finally84;
	__catch84_g_error:
	{
		GError* _error_ = NULL;
		const gchar* _tmp14_ = NULL;
		GError* _tmp15_ = NULL;
		const gchar* _tmp16_ = NULL;
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_error_ = _inner_error_;
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_inner_error_ = NULL;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp14_ = path;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp15_ = _error_;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp16_ = _tmp15_->message;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_warning ("util-app.vala:224: Error loading logo file '%s': %s", _tmp14_, _tmp16_);
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (_error_);
#line 2250 "util-app.c"
	}
	__finally84:
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_inner_error_ != NULL) {
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (path);
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_clear_error (&_inner_error_);
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return;
#line 2263 "util-app.c"
	}
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (path);
#line 2267 "util-app.c"
}


GVirStoragePool* boxes_get_storage_pool (GVirConnection* connection) {
	GVirStoragePool* result = NULL;
	GVirConnection* _tmp0_ = NULL;
	GVirStoragePool* _tmp1_ = NULL;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (connection != NULL, NULL);
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = connection;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = gvir_connection_find_storage_pool_by_name (_tmp0_, PACKAGE_TARNAME);
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = _tmp1_;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 2285 "util-app.c"
}


GVirStorageVol* boxes_get_storage_volume (GVirConnection* connection, GVirDomain* domain) {
	GVirStorageVol* result = NULL;
	GVirStoragePool* pool = NULL;
	GVirConnection* _tmp0_ = NULL;
	GVirStoragePool* _tmp1_ = NULL;
	GVirStoragePool* _tmp2_ = NULL;
	GVirStoragePool* _tmp3_ = NULL;
	GVirDomain* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	GVirStorageVol* _tmp6_ = NULL;
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (connection != NULL, NULL);
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (domain != NULL, NULL);
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = connection;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = boxes_get_storage_pool (_tmp0_);
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	pool = _tmp1_;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = pool;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp2_ == NULL) {
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		result = NULL;
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (pool);
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return result;
#line 2319 "util-app.c"
	}
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = pool;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_ = domain;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = gvir_domain_get_name (_tmp4_);
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp6_ = gvir_storage_pool_get_volume (_tmp3_, _tmp5_);
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = _tmp6_;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (pool);
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 2335 "util-app.c"
}


static gchar string_get (const gchar* self, glong index) {
	gchar result = '\0';
	glong _tmp0_ = 0L;
	gchar _tmp1_ = '\0';
#line 965 "/home/zeenix/jhbuild/share/vala-0.22/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, '\0');
#line 966 "/home/zeenix/jhbuild/share/vala-0.22/vapi/glib-2.0.vapi"
	_tmp0_ = index;
#line 966 "/home/zeenix/jhbuild/share/vala-0.22/vapi/glib-2.0.vapi"
	_tmp1_ = ((gchar*) self)[_tmp0_];
#line 966 "/home/zeenix/jhbuild/share/vala-0.22/vapi/glib-2.0.vapi"
	result = _tmp1_;
#line 966 "/home/zeenix/jhbuild/share/vala-0.22/vapi/glib-2.0.vapi"
	return result;
#line 2353 "util-app.c"
}


gboolean boxes_is_libvirt_bridge_net_available (void) {
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp35_ = FALSE;
	GError * _inner_error_ = NULL;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = boxes_libvirt_bridge_net_checked;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp0_) {
#line 2366 "util-app.c"
		gboolean _tmp1_ = FALSE;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp1_ = boxes_libvirt_bridge_net_available;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		result = _tmp1_;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return result;
#line 2374 "util-app.c"
	}
	{
		gint sock = 0;
		gint _tmp2_ = 0;
		gint _tmp3_ = 0;
		struct ifreq req = {0};
		gchar* if_name = NULL;
		gchar* _tmp7_ = NULL;
		gboolean _tmp20_ = FALSE;
		gint _tmp21_ = 0;
		gint _tmp22_ = 0;
		gboolean _tmp25_ = FALSE;
		GFile* file = NULL;
		GFile* _tmp27_ = NULL;
		guint8* contents = NULL;
		gint contents_length1 = 0;
		gint _contents_size_ = 0;
		GFile* _tmp28_ = NULL;
		guint8* _tmp29_ = NULL;
		gsize _tmp30_;
		guint8* _tmp31_ = NULL;
		gint _tmp31__length1 = 0;
		gboolean _tmp32_ = FALSE;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp2_ = socket (AF_INET, SOCK_STREAM, 0);
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		sock = _tmp2_;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp3_ = sock;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_tmp3_ < 0) {
#line 2406 "util-app.c"
			gint _tmp4_ = 0;
			gint _tmp5_ = 0;
			GError* _tmp6_ = NULL;
#line 252 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp4_ = errno;
#line 252 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp5_ = g_io_error_from_errno (_tmp4_);
#line 252 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp6_ = g_error_new ((GQuark) G_IO_ERROR, _tmp5_, "Failed to create a socket");
#line 252 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_inner_error_ = (GError*) _tmp6_;
#line 2418 "util-app.c"
			goto __catch85_g_error;
		}
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		memset (&req, 0, sizeof (struct ifreq));
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp7_ = g_strdup ("virbr0");
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if_name = _tmp7_;
#line 2427 "util-app.c"
		{
			gint i = 0;
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			i = 0;
#line 2432 "util-app.c"
			{
				gboolean _tmp8_ = FALSE;
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp8_ = TRUE;
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				while (TRUE) {
#line 2439 "util-app.c"
					gboolean _tmp9_ = FALSE;
					gint _tmp11_ = 0;
					const gchar* _tmp12_ = NULL;
					gint _tmp13_ = 0;
					gint _tmp14_ = 0;
					gint _tmp15_ = 0;
					const gchar* _tmp16_ = NULL;
					gint _tmp17_ = 0;
					gchar _tmp18_ = '\0';
					gchar _tmp19_ = '\0';
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					_tmp9_ = _tmp8_;
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					if (!_tmp9_) {
#line 2454 "util-app.c"
						gint _tmp10_ = 0;
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
						_tmp10_ = i;
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
						i = _tmp10_ + 1;
#line 2460 "util-app.c"
					}
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					_tmp8_ = FALSE;
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					_tmp11_ = i;
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					_tmp12_ = if_name;
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					_tmp13_ = strlen (_tmp12_);
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					_tmp14_ = _tmp13_;
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					if (!(_tmp11_ <= _tmp14_)) {
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
						break;
#line 2476 "util-app.c"
					}
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					_tmp15_ = i;
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					_tmp16_ = if_name;
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					_tmp17_ = i;
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					_tmp18_ = string_get (_tmp16_, (glong) _tmp17_);
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					req.ifr_name[_tmp15_] = (gchar) _tmp18_;
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					_tmp19_ = req.ifr_name[_tmp15_];
#line 2490 "util-app.c"
				}
			}
		}
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp21_ = sock;
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp22_ = ioctl (_tmp21_, SIOCGIFFLAGS, &req);
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_tmp22_ < 0) {
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp20_ = TRUE;
#line 2502 "util-app.c"
		} else {
			struct ifreq _tmp23_ = {0};
			gshort _tmp24_ = 0;
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp23_ = req;
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp24_ = _tmp23_.ifr_flags;
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp20_ = !((_tmp24_ & IFF_UP) == IFF_UP);
#line 2512 "util-app.c"
		}
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp25_ = _tmp20_;
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_tmp25_) {
#line 2518 "util-app.c"
			const gchar* _tmp26_ = NULL;
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp26_ = if_name;
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_debug ("util-app.vala:263: Interface '%s' is either not available or not up.", _tmp26_);
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			result = FALSE;
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (if_name);
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			 (&req);
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			return result;
#line 2532 "util-app.c"
		}
#line 269 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp27_ = g_file_new_for_path ("/etc/qemu/bridge.conf");
#line 269 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		file = _tmp27_;
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp28_ = file;
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_file_load_contents (_tmp28_, NULL, &_tmp29_, &_tmp30_, NULL, &_inner_error_);
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		contents = (g_free (contents), NULL);
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		contents = _tmp29_;
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		contents_length1 = _tmp30_;
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_contents_size_ = contents_length1;
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_inner_error_ != NULL) {
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			contents = (g_free (contents), NULL);
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_object_unref0 (file);
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (if_name);
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			 (&req);
#line 2560 "util-app.c"
			goto __catch85_g_error;
		}
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp31_ = contents;
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp31__length1 = contents_length1;
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp32_ = g_regex_match_simple ("^allow.*virbr0", (const gchar*) _tmp31_, 0, 0);
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		boxes_libvirt_bridge_net_available = _tmp32_;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		contents = (g_free (contents), NULL);
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (file);
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (if_name);
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		 (&req);
#line 2579 "util-app.c"
	}
	goto __finally85;
	__catch85_g_error:
	{
		GError* _error_ = NULL;
		GError* _tmp33_ = NULL;
		const gchar* _tmp34_ = NULL;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_error_ = _inner_error_;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_inner_error_ = NULL;
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp33_ = _error_;
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp34_ = _tmp33_->message;
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_debug ("util-app.vala:275: %s", _tmp34_);
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		boxes_libvirt_bridge_net_available = FALSE;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (_error_);
#line 2601 "util-app.c"
	}
	__finally85:
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_inner_error_ != NULL) {
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_clear_error (&_inner_error_);
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 2612 "util-app.c"
	}
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	boxes_libvirt_bridge_net_checked = TRUE;
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp35_ = boxes_libvirt_bridge_net_available;
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = _tmp35_;
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 2622 "util-app.c"
}


gchar* boxes_get_logo_path (OsinfoOs* os, gchar** extensions, int extensions_length1) {
	gchar* result = NULL;
	gchar** _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
	gchar* path = NULL;
	OsinfoOs* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gchar** _tmp4_ = NULL;
	gint _tmp4__length1 = 0;
	const gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	GFile* file = NULL;
	const gchar* _tmp10_ = NULL;
	GFile* _tmp11_ = NULL;
	GFile* _tmp12_ = NULL;
	gboolean _tmp13_ = FALSE;
	GFile* _tmp24_ = NULL;
	gboolean _tmp25_ = FALSE;
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (os != NULL, NULL);
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = extensions;
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0__length1 = extensions_length1;
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp0__length1 == 0) {
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		result = NULL;
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return result;
#line 2660 "util-app.c"
	}
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = os;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = osinfo_product_get_short_id ((OsinfoProduct*) _tmp1_);
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = _tmp2_;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_ = extensions;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4__length1 = extensions_length1;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = _tmp4_[0];
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp6_ = g_strconcat (_tmp3_, _tmp5_, NULL);
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp7_ = _tmp6_;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp8_ = boxes_get_pixmap (_tmp7_);
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp9_ = _tmp8_;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (_tmp7_);
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	path = _tmp9_;
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp10_ = path;
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp11_ = g_file_new_for_path (_tmp10_);
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	file = _tmp11_;
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp12_ = file;
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp13_ = g_file_query_exists (_tmp12_, NULL);
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (!_tmp13_) {
#line 2698 "util-app.c"
		OsinfoOs* _tmp14_ = NULL;
		const gchar* _tmp15_ = NULL;
		const gchar* _tmp16_ = NULL;
		gchar** _tmp17_ = NULL;
		gint _tmp17__length1 = 0;
		const gchar* _tmp18_ = NULL;
		gchar* _tmp19_ = NULL;
		gchar* _tmp20_ = NULL;
		gchar* _tmp21_ = NULL;
		const gchar* _tmp22_ = NULL;
		GFile* _tmp23_ = NULL;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp14_ = os;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp15_ = osinfo_os_get_distro (_tmp14_);
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp16_ = _tmp15_;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp17_ = extensions;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp17__length1 = extensions_length1;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp18_ = _tmp17_[0];
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp19_ = g_strconcat (_tmp16_, _tmp18_, NULL);
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp20_ = _tmp19_;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp21_ = boxes_get_pixmap (_tmp20_);
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (path);
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		path = _tmp21_;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_tmp20_);
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp22_ = path;
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp23_ = g_file_new_for_path (_tmp22_);
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (file);
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		file = _tmp23_;
#line 2742 "util-app.c"
	}
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp24_ = file;
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp25_ = g_file_query_exists (_tmp24_, NULL);
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp25_) {
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		result = path;
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (file);
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return result;
#line 2756 "util-app.c"
	} else {
		OsinfoOs* _tmp26_ = NULL;
		gchar** _tmp27_ = NULL;
		gint _tmp27__length1 = 0;
		gchar** _tmp28_ = NULL;
		gint _tmp28__length1 = 0;
		gchar* _tmp29_ = NULL;
#line 299 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp26_ = os;
#line 299 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp27_ = extensions;
#line 299 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp27__length1 = extensions_length1;
#line 299 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp28_ = extensions;
#line 299 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp28__length1 = extensions_length1;
#line 299 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp29_ = boxes_get_logo_path (_tmp26_, _tmp27_ + 1, _tmp28__length1 - 1);
#line 299 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		result = _tmp29_;
#line 299 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (file);
#line 299 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (path);
#line 299 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return result;
#line 2784 "util-app.c"
	}
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (file);
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (path);
#line 2790 "util-app.c"
}


static void boxes_check_selinux_context_default_data_free (gpointer _data) {
	BoxesCheckSelinuxContextDefaultData* _data_;
	_data_ = _data;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesCheckSelinuxContextDefaultData, _data_);
#line 2799 "util-app.c"
}


void boxes_check_selinux_context_default (GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesCheckSelinuxContextDefaultData* _data_;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesCheckSelinuxContextDefaultData);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_check_selinux_context_default);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_check_selinux_context_default_data_free);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_check_selinux_context_default_co (_data_);
#line 2813 "util-app.c"
}


gboolean boxes_check_selinux_context_default_finish (GAsyncResult* _res_, gchar** diagnosis) {
	gboolean result;
	BoxesCheckSelinuxContextDefaultData* _data_;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (diagnosis) {
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		*diagnosis = _data_->diagnosis;
#line 2826 "util-app.c"
	} else {
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_free0 (_data_->diagnosis);
#line 2830 "util-app.c"
	}
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->diagnosis = NULL;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = _data_->result;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 2838 "util-app.c"
}


static void boxes_check_selinux_context_default_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesCheckSelinuxContextDefaultData* _data_;
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_ = _user_data_;
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_source_object_ = source_object;
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_res_ = _res_;
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	boxes_check_selinux_context_default_co (_data_);
#line 2852 "util-app.c"
}


static gboolean boxes_check_selinux_context_default_co (BoxesCheckSelinuxContextDefaultData* _data_) {
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	switch (_data_->_state_) {
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 0:
#line 2861 "util-app.c"
		goto _state_0;
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 1:
#line 2865 "util-app.c"
		goto _state_1;
		default:
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_assert_not_reached ();
#line 2870 "util-app.c"
	}
	_state_0:
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp0_ = NULL;
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp0_ = g_strdup ("");
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (_data_->diagnosis);
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->diagnosis = _data_->_tmp0_;
#line 2881 "util-app.c"
	{
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp1_ = NULL;
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp1_ = g_strdup ("restorecon");
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_ = NULL;
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_ = g_strdup ("-nrv");
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3_ = NULL;
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3_ = boxes_get_user_pkgconfig (NULL);
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_ = NULL;
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_ = boxes_get_user_pkgdata (NULL);
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp5_ = NULL;
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp5_ = boxes_get_user_pkgcache (NULL);
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_ = NULL;
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_ = g_new0 (gchar*, 5 + 1);
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_[0] = _data_->_tmp1_;
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_[1] = _data_->_tmp2_;
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_[2] = _data_->_tmp3_;
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_[3] = _data_->_tmp4_;
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_[4] = _data_->_tmp5_;
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->argv_length1 = 0;
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_argv_size_ = 0;
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->argv = _data_->_tmp6_;
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->argv_length1 = 5;
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_argv_size_ = _data_->argv_length1;
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp7_ = NULL;
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp7__length1 = 0;
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp7_ = _data_->argv;
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp7__length1 = _data_->argv_length1;
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp8_ = NULL;
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_state_ = 1;
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		boxes_exec (_data_->_tmp7_, _data_->_tmp7__length1, NULL, boxes_check_selinux_context_default_ready, _data_);
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 2943 "util-app.c"
		_state_1:
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		boxes_exec_finish (_data_->_res_, &_data_->_tmp8_, NULL, &_data_->_inner_error_);
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->standard_output);
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->standard_output = _data_->_tmp8_;
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_inner_error_ != NULL) {
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->argv = (_vala_array_free (_data_->argv, _data_->argv_length1, (GDestroyNotify) g_free), NULL);
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (_data_->standard_output);
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (g_error_matches (_data_->_inner_error_, G_SPAWN_ERROR, G_SPAWN_ERROR_NOEXEC)) {
#line 2959 "util-app.c"
				goto __catch86_g_spawn_error_noexec;
			}
			goto __catch86_g_error;
		}
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp9_ = NULL;
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp9_ = _data_->standard_output;
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp10_ = 0;
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp10_ = strlen (_data_->_tmp9_);
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp11_ = 0;
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp11_ = _data_->_tmp10_;
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_tmp11_ == 0) {
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->result = TRUE;
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->argv = (_vala_array_free (_data_->argv, _data_->argv_length1, (GDestroyNotify) g_free), NULL);
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (_data_->standard_output);
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (_data_->_state_ == 0) {
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2988 "util-app.c"
			} else {
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 2992 "util-app.c"
			}
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_object_unref (_data_->_async_result);
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			return FALSE;
#line 2998 "util-app.c"
		}
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp12_ = NULL;
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp12__length1 = 0;
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp12_ = _data_->argv;
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp12__length1 = _data_->argv_length1;
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp13_ = NULL;
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp13_ = g_strdup ("-r");
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->_tmp12_[1]);
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp12_[1] = _data_->_tmp13_;
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp14_ = NULL;
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp14_ = _data_->_tmp12_[1];
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp15_ = NULL;
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp15_ = _ ("Your SELinux context looks incorrect, you can try to fix it by running" \
":\n" \
"%s");
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp16_ = NULL;
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp16__length1 = 0;
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp16_ = _data_->argv;
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp16__length1 = _data_->argv_length1;
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp17_ = NULL;
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp17_ = g_strjoinv (" ", _data_->_tmp16_);
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp18_ = NULL;
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp18_ = _data_->_tmp17_;
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp19_ = NULL;
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp19_ = g_strdup_printf (_data_->_tmp15_, _data_->_tmp18_);
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->diagnosis);
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->diagnosis = _data_->_tmp19_;
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->_tmp18_);
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->result = FALSE;
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->argv = (_vala_array_free (_data_->argv, _data_->argv_length1, (GDestroyNotify) g_free), NULL);
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->standard_output);
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_state_ == 0) {
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3060 "util-app.c"
		} else {
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3064 "util-app.c"
		}
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_object_unref (_data_->_async_result);
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 3070 "util-app.c"
	}
	goto __finally86;
	__catch86_g_spawn_error_noexec:
	{
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_inner_error_ = NULL;
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp20_ = NULL;
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp20_ = _ ("SELinux not installed?");
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp21_ = NULL;
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp21_ = g_strdup (_data_->_tmp20_);
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->diagnosis);
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->diagnosis = _data_->_tmp21_;
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->result = TRUE;
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (_data_->_error_);
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_state_ == 0) {
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3099 "util-app.c"
		} else {
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3103 "util-app.c"
		}
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_object_unref (_data_->_async_result);
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 3109 "util-app.c"
	}
	goto __finally86;
	__catch86_g_error:
	{
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_vala1__error_ = _data_->_inner_error_;
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_inner_error_ = NULL;
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp22_ = NULL;
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp22_ = _data_->_vala1__error_;
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp23_ = NULL;
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp23_ = _data_->_tmp22_->message;
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_warning ("util-app.vala:329: %s", _data_->_tmp23_);
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (_data_->_vala1__error_);
#line 3130 "util-app.c"
	}
	__finally86:
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_inner_error_ != NULL) {
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_clear_error (&_data_->_inner_error_);
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 3141 "util-app.c"
	}
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->result = FALSE;
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_state_ == 0) {
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3149 "util-app.c"
	} else {
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3153 "util-app.c"
	}
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_unref (_data_->_async_result);
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_state_ == 0) {
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3163 "util-app.c"
	} else {
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3167 "util-app.c"
	}
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_unref (_data_->_async_result);
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 3173 "util-app.c"
}


static void boxes_check_libvirt_kvm_data_free (gpointer _data) {
	BoxesCheckLibvirtKvmData* _data_;
	_data_ = _data;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesCheckLibvirtKvmData, _data_);
#line 3182 "util-app.c"
}


void boxes_check_libvirt_kvm (GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesCheckLibvirtKvmData* _data_;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesCheckLibvirtKvmData);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_check_libvirt_kvm);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_check_libvirt_kvm_data_free);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_check_libvirt_kvm_co (_data_);
#line 3196 "util-app.c"
}


gboolean boxes_check_libvirt_kvm_finish (GAsyncResult* _res_) {
	gboolean result;
	BoxesCheckLibvirtKvmData* _data_;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = _data_->result;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 3209 "util-app.c"
}


static void boxes_check_libvirt_kvm_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesCheckLibvirtKvmData* _data_;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_ = _user_data_;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_source_object_ = source_object;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_res_ = _res_;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	boxes_check_libvirt_kvm_co (_data_);
#line 3223 "util-app.c"
}


static gboolean boxes_check_libvirt_kvm_co (BoxesCheckLibvirtKvmData* _data_) {
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	switch (_data_->_state_) {
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 0:
#line 3232 "util-app.c"
		goto _state_0;
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 1:
#line 3236 "util-app.c"
		goto _state_1;
		default:
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_assert_not_reached ();
#line 3241 "util-app.c"
	}
	_state_0:
	{
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp0_ = NULL;
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp0_ = g_strdup ("virsh");
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp1_ = NULL;
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp1_ = g_strdup ("capabilities");
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_ = NULL;
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_ = g_new0 (gchar*, 2 + 1);
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_[0] = _data_->_tmp0_;
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_[1] = _data_->_tmp1_;
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->argv_length1 = 0;
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_argv_size_ = 0;
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->argv = _data_->_tmp2_;
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->argv_length1 = 2;
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_argv_size_ = _data_->argv_length1;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3_ = NULL;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3__length1 = 0;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3_ = _data_->argv;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3__length1 = _data_->argv_length1;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_ = NULL;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_state_ = 1;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		boxes_exec (_data_->_tmp3_, _data_->_tmp3__length1, NULL, boxes_check_libvirt_kvm_ready, _data_);
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 3287 "util-app.c"
		_state_1:
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		boxes_exec_finish (_data_->_res_, &_data_->_tmp4_, NULL, &_data_->_inner_error_);
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->standard_output);
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->standard_output = _data_->_tmp4_;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_inner_error_ != NULL) {
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->argv = (_vala_array_free (_data_->argv, _data_->argv_length1, (GDestroyNotify) g_free), NULL);
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (_data_->standard_output);
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (g_error_matches (_data_->_inner_error_, G_SPAWN_ERROR, G_SPAWN_ERROR_NOEXEC)) {
#line 3303 "util-app.c"
				goto __catch87_g_spawn_error_noexec;
			}
			goto __catch87_g_error;
		}
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp5_ = NULL;
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp5_ = _data_->standard_output;
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_ = NULL;
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_ = boxes_extract_xpath (_data_->_tmp5_, "string(/capabilities/guest[os_type='hvm']/arch/domain[@type='kvm']/emu" \
"lator)", FALSE, &_data_->_inner_error_);
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->kvm = _data_->_tmp6_;
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_inner_error_ != NULL) {
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->argv = (_vala_array_free (_data_->argv, _data_->argv_length1, (GDestroyNotify) g_free), NULL);
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (_data_->standard_output);
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (g_error_matches (_data_->_inner_error_, G_SPAWN_ERROR, G_SPAWN_ERROR_NOEXEC)) {
#line 3326 "util-app.c"
				goto __catch87_g_spawn_error_noexec;
			}
			goto __catch87_g_error;
		}
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp7_ = NULL;
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp7_ = _data_->kvm;
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp8_ = 0;
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp8_ = strlen (_data_->_tmp7_);
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp9_ = 0;
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp9_ = _data_->_tmp8_;
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->result = _data_->_tmp9_ != 0;
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->kvm);
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->argv = (_vala_array_free (_data_->argv, _data_->argv_length1, (GDestroyNotify) g_free), NULL);
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->standard_output);
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_state_ == 0) {
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3355 "util-app.c"
		} else {
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3359 "util-app.c"
		}
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_object_unref (_data_->_async_result);
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 3365 "util-app.c"
	}
	goto __finally87;
	__catch87_g_spawn_error_noexec:
	{
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_inner_error_ = NULL;
#line 346 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_critical ("util-app.vala:346: libvirt is not installed correctly");
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (_data_->_error_);
#line 3378 "util-app.c"
	}
	goto __finally87;
	__catch87_g_error:
	{
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_vala1__error_ = _data_->_inner_error_;
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_inner_error_ = NULL;
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp10_ = NULL;
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp10_ = _data_->_vala1__error_;
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp11_ = NULL;
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp11_ = _data_->_tmp10_->message;
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_warning ("util-app.vala:348: %s", _data_->_tmp11_);
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (_data_->_vala1__error_);
#line 3399 "util-app.c"
	}
	__finally87:
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_inner_error_ != NULL) {
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_clear_error (&_data_->_inner_error_);
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 3410 "util-app.c"
	}
#line 351 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->result = FALSE;
#line 351 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_state_ == 0) {
#line 351 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3418 "util-app.c"
	} else {
#line 351 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3422 "util-app.c"
	}
#line 351 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_unref (_data_->_async_result);
#line 351 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_state_ == 0) {
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3432 "util-app.c"
	} else {
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3436 "util-app.c"
	}
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_unref (_data_->_async_result);
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 3442 "util-app.c"
}


static void boxes_check_cpu_vt_capability_data_free (gpointer _data) {
	BoxesCheckCpuVtCapabilityData* _data_;
	_data_ = _data;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesCheckCpuVtCapabilityData, _data_);
#line 3451 "util-app.c"
}


void boxes_check_cpu_vt_capability (GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesCheckCpuVtCapabilityData* _data_;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesCheckCpuVtCapabilityData);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_check_cpu_vt_capability);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_check_cpu_vt_capability_data_free);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_check_cpu_vt_capability_co (_data_);
#line 3465 "util-app.c"
}


gboolean boxes_check_cpu_vt_capability_finish (GAsyncResult* _res_) {
	gboolean result;
	BoxesCheckCpuVtCapabilityData* _data_;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = _data_->result;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 3478 "util-app.c"
}


static void boxes_check_cpu_vt_capability_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesCheckCpuVtCapabilityData* _data_;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_ = _user_data_;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_source_object_ = source_object;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_res_ = _res_;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	boxes_check_cpu_vt_capability_co (_data_);
#line 3492 "util-app.c"
}


static inline GRegex* _thread_safe_regex_init (GRegex** re, const gchar * pattern, GRegexMatchFlags match_options) {
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (g_once_init_enter ((volatile gsize*) re)) {
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		GRegex* val = g_regex_new (pattern, match_options, 0, NULL);
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_once_init_leave ((volatile gsize*) re, (gsize) val);
#line 3503 "util-app.c"
	}
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return *re;
#line 3507 "util-app.c"
}


static gboolean boxes_check_cpu_vt_capability_co (BoxesCheckCpuVtCapabilityData* _data_) {
#line 354 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	switch (_data_->_state_) {
#line 354 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 0:
#line 3516 "util-app.c"
		goto _state_0;
#line 354 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 1:
#line 3520 "util-app.c"
		goto _state_1;
		default:
#line 354 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_assert_not_reached ();
#line 3525 "util-app.c"
	}
	_state_0:
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_result_ = FALSE;
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp0_ = NULL;
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp0_ = g_file_new_for_path ("/proc/cpuinfo");
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->file = _data_->_tmp0_;
#line 3536 "util-app.c"
	{
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_ = NULL;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_ = _data_->file;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3_ = NULL;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3_ = g_file_read (_data_->_tmp2_, NULL, &_data_->_inner_error_);
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp1_ = _data_->_tmp3_;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_inner_error_ != NULL) {
#line 3550 "util-app.c"
			goto __catch88_g_error;
		}
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_ = NULL;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_ = _data_->_tmp1_;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp5_ = NULL;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp5_ = g_data_input_stream_new ((GInputStream*) _data_->_tmp4_);
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_ = NULL;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_ = _data_->_tmp5_;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (_data_->_tmp4_);
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->stream = _data_->_tmp6_;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->line = NULL;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		while (TRUE) {
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp8_ = NULL;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp8_ = _data_->stream;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_state_ = 1;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_data_input_stream_read_line_async (_data_->_tmp8_, G_PRIORITY_DEFAULT, NULL, boxes_check_cpu_vt_capability_ready, _data_);
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			return FALSE;
#line 3583 "util-app.c"
			_state_1:
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp9_ = NULL;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp9_ = g_data_input_stream_read_line_finish (_data_->_tmp8_, _data_->_res_, NULL, &_data_->_inner_error_);
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp7_ = _data_->_tmp9_;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (_data_->_inner_error_ != NULL) {
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_g_free0 (_data_->line);
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_g_object_unref0 (_data_->stream);
#line 3597 "util-app.c"
				goto __catch88_g_error;
			}
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (_data_->line);
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->line = _data_->_tmp7_;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp10_ = NULL;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp10_ = _data_->line;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (!(_data_->_tmp10_ != NULL)) {
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				break;
#line 3612 "util-app.c"
			}
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp11_ = NULL;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp11_ = _data_->line;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp12_ = FALSE;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp12_ = g_regex_match (_thread_safe_regex_init (&_tmp_regex_0, "^flags.*(vmx|svm)", 0), _data_->_tmp11_, 0, NULL);
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_result_ = _data_->_tmp12_;
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp13_ = FALSE;
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp13_ = _data_->_result_;
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (_data_->_tmp13_) {
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				break;
#line 3632 "util-app.c"
			}
		}
#line 358 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->line);
#line 358 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (_data_->stream);
#line 3639 "util-app.c"
	}
	goto __finally88;
	__catch88_g_error:
	{
#line 358 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 358 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_inner_error_ = NULL;
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp14_ = NULL;
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp14_ = _data_->_error_->message;
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_error ("util-app.vala:367: %s", _data_->_tmp14_);
#line 358 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (_data_->_error_);
#line 3656 "util-app.c"
	}
	__finally88:
#line 358 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_inner_error_ != NULL) {
#line 358 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (_data_->file);
#line 358 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 358 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_clear_error (&_data_->_inner_error_);
#line 358 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 3669 "util-app.c"
	}
#line 370 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp15_ = FALSE;
#line 370 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp15_ = _data_->_result_;
#line 370 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp16_ = NULL;
#line 370 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp16_ = boxes_yes_no (_data_->_tmp15_);
#line 370 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp17_ = NULL;
#line 370 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp17_ = _data_->_tmp16_;
#line 370 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp18_ = NULL;
#line 370 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp18_ = g_strconcat ("check_cpu_vt_capability: ", _data_->_tmp17_, NULL);
#line 370 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp19_ = NULL;
#line 370 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp19_ = _data_->_tmp18_;
#line 370 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_debug ("util-app.vala:370: %s", _data_->_tmp19_);
#line 370 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (_data_->_tmp19_);
#line 370 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (_data_->_tmp17_);
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->result = _data_->_result_;
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (_data_->file);
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_state_ == 0) {
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3705 "util-app.c"
	} else {
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3709 "util-app.c"
	}
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_unref (_data_->_async_result);
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 354 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (_data_->file);
#line 354 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_state_ == 0) {
#line 354 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3721 "util-app.c"
	} else {
#line 354 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3725 "util-app.c"
	}
#line 354 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_unref (_data_->_async_result);
#line 354 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 3731 "util-app.c"
}


static void boxes_check_module_kvm_loaded_data_free (gpointer _data) {
	BoxesCheckModuleKvmLoadedData* _data_;
	_data_ = _data;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesCheckModuleKvmLoadedData, _data_);
#line 3740 "util-app.c"
}


void boxes_check_module_kvm_loaded (GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesCheckModuleKvmLoadedData* _data_;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesCheckModuleKvmLoadedData);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_check_module_kvm_loaded);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_check_module_kvm_loaded_data_free);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_check_module_kvm_loaded_co (_data_);
#line 3754 "util-app.c"
}


gboolean boxes_check_module_kvm_loaded_finish (GAsyncResult* _res_) {
	gboolean result;
	BoxesCheckModuleKvmLoadedData* _data_;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = _data_->result;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 3767 "util-app.c"
}


static void boxes_check_module_kvm_loaded_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesCheckModuleKvmLoadedData* _data_;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_ = _user_data_;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_source_object_ = source_object;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_res_ = _res_;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	boxes_check_module_kvm_loaded_co (_data_);
#line 3781 "util-app.c"
}


static gboolean boxes_check_module_kvm_loaded_co (BoxesCheckModuleKvmLoadedData* _data_) {
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	switch (_data_->_state_) {
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 0:
#line 3790 "util-app.c"
		goto _state_0;
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 1:
#line 3794 "util-app.c"
		goto _state_1;
		default:
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_assert_not_reached ();
#line 3799 "util-app.c"
	}
	_state_0:
#line 375 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_result_ = FALSE;
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp0_ = NULL;
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp0_ = g_file_new_for_path ("/proc/modules");
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->file = _data_->_tmp0_;
#line 3810 "util-app.c"
	{
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_ = NULL;
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_ = _data_->file;
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3_ = NULL;
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3_ = g_file_read (_data_->_tmp2_, NULL, &_data_->_inner_error_);
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp1_ = _data_->_tmp3_;
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_inner_error_ != NULL) {
#line 3824 "util-app.c"
			goto __catch89_g_error;
		}
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_ = NULL;
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_ = _data_->_tmp1_;
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp5_ = NULL;
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp5_ = g_data_input_stream_new ((GInputStream*) _data_->_tmp4_);
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_ = NULL;
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_ = _data_->_tmp5_;
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (_data_->_tmp4_);
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->stream = _data_->_tmp6_;
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->line = NULL;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		while (TRUE) {
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp8_ = NULL;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp8_ = _data_->stream;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_state_ = 1;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_data_input_stream_read_line_async (_data_->_tmp8_, G_PRIORITY_DEFAULT, NULL, boxes_check_module_kvm_loaded_ready, _data_);
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			return FALSE;
#line 3857 "util-app.c"
			_state_1:
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp9_ = NULL;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp9_ = g_data_input_stream_read_line_finish (_data_->_tmp8_, _data_->_res_, NULL, &_data_->_inner_error_);
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp7_ = _data_->_tmp9_;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (_data_->_inner_error_ != NULL) {
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_g_free0 (_data_->line);
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_g_object_unref0 (_data_->stream);
#line 3871 "util-app.c"
				goto __catch89_g_error;
			}
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (_data_->line);
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->line = _data_->_tmp7_;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp10_ = NULL;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp10_ = _data_->line;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (!(_data_->_tmp10_ != NULL)) {
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				break;
#line 3886 "util-app.c"
			}
#line 382 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp11_ = NULL;
#line 382 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp11_ = _data_->line;
#line 382 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp12_ = FALSE;
#line 382 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp12_ = g_regex_match (_thread_safe_regex_init (&_tmp_regex_1, "^(kvm_intel|kvm_amd)", 0), _data_->_tmp11_, 0, NULL);
#line 382 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_result_ = _data_->_tmp12_;
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp13_ = FALSE;
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->_tmp13_ = _data_->_result_;
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (_data_->_tmp13_) {
#line 384 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				break;
#line 3906 "util-app.c"
			}
		}
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->line);
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (_data_->stream);
#line 3913 "util-app.c"
	}
	goto __finally89;
	__catch89_g_error:
	{
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_inner_error_ = NULL;
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp14_ = NULL;
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp14_ = _data_->_error_->message;
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_error ("util-app.vala:387: %s", _data_->_tmp14_);
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (_data_->_error_);
#line 3930 "util-app.c"
	}
	__finally89:
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_inner_error_ != NULL) {
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (_data_->file);
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_clear_error (&_data_->_inner_error_);
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 3943 "util-app.c"
	}
#line 390 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp15_ = FALSE;
#line 390 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp15_ = _data_->_result_;
#line 390 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp16_ = NULL;
#line 390 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp16_ = boxes_yes_no (_data_->_tmp15_);
#line 390 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp17_ = NULL;
#line 390 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp17_ = _data_->_tmp16_;
#line 390 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp18_ = NULL;
#line 390 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp18_ = g_strconcat ("check_module_kvm_loaded: ", _data_->_tmp17_, NULL);
#line 390 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp19_ = NULL;
#line 390 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp19_ = _data_->_tmp18_;
#line 390 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_debug ("util-app.vala:390: %s", _data_->_tmp19_);
#line 390 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (_data_->_tmp19_);
#line 390 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (_data_->_tmp17_);
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->result = _data_->_result_;
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (_data_->file);
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_state_ == 0) {
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3979 "util-app.c"
	} else {
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3983 "util-app.c"
	}
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_unref (_data_->_async_result);
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (_data_->file);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_state_ == 0) {
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3995 "util-app.c"
	} else {
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3999 "util-app.c"
	}
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_unref (_data_->_async_result);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 4005 "util-app.c"
}


static void boxes_check_storage_pool_data_free (gpointer _data) {
	BoxesCheckStoragePoolData* _data_;
	_data_ = _data;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesCheckStoragePoolData, _data_);
#line 4014 "util-app.c"
}


void boxes_check_storage_pool (GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesCheckStoragePoolData* _data_;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesCheckStoragePoolData);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_check_storage_pool);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_check_storage_pool_data_free);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_check_storage_pool_co (_data_);
#line 4028 "util-app.c"
}


gboolean boxes_check_storage_pool_finish (GAsyncResult* _res_, gchar** diagnosis) {
	gboolean result;
	BoxesCheckStoragePoolData* _data_;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (diagnosis) {
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		*diagnosis = _data_->diagnosis;
#line 4041 "util-app.c"
	} else {
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_free0 (_data_->diagnosis);
#line 4045 "util-app.c"
	}
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->diagnosis = NULL;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = _data_->result;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 4053 "util-app.c"
}


static void boxes_check_storage_pool_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesCheckStoragePoolData* _data_;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_ = _user_data_;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_source_object_ = source_object;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_res_ = _res_;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	boxes_check_storage_pool_co (_data_);
#line 4067 "util-app.c"
}


static gboolean boxes_check_storage_pool_co (BoxesCheckStoragePoolData* _data_) {
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	switch (_data_->_state_) {
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 0:
#line 4076 "util-app.c"
		goto _state_0;
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 1:
#line 4080 "util-app.c"
		goto _state_1;
		default:
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_assert_not_reached ();
#line 4085 "util-app.c"
	}
	_state_0:
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp0_ = NULL;
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp0_ = g_strdup ("");
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (_data_->diagnosis);
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->diagnosis = _data_->_tmp0_;
#line 4096 "util-app.c"
	{
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp1_ = NULL;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp1_ = g_strdup ("virsh");
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_ = NULL;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_ = g_strdup ("pool-dumpxml");
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3_ = NULL;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3_ = g_strdup (PACKAGE_TARNAME);
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_ = NULL;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_ = g_new0 (gchar*, 3 + 1);
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_[0] = _data_->_tmp1_;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_[1] = _data_->_tmp2_;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_[2] = _data_->_tmp3_;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->argv_length1 = 0;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_argv_size_ = 0;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->argv = _data_->_tmp4_;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->argv_length1 = 3;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_argv_size_ = _data_->argv_length1;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp5_ = NULL;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp5__length1 = 0;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp5_ = _data_->argv;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp5__length1 = _data_->argv_length1;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_ = NULL;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_state_ = 1;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		boxes_exec (_data_->_tmp5_, _data_->_tmp5__length1, NULL, boxes_check_storage_pool_ready, _data_);
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 4146 "util-app.c"
		_state_1:
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		boxes_exec_finish (_data_->_res_, &_data_->_tmp6_, NULL, &_data_->_inner_error_);
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->standard_output);
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->standard_output = _data_->_tmp6_;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_inner_error_ != NULL) {
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->argv = (_vala_array_free (_data_->argv, _data_->argv_length1, (GDestroyNotify) g_free), NULL);
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (_data_->standard_output);
#line 4160 "util-app.c"
			goto __catch90_g_error;
		}
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp8_ = NULL;
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp8_ = _data_->standard_output;
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp9_ = NULL;
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp9_ = boxes_extract_xpath (_data_->_tmp8_, "string(/pool[@type='dir']/target/path)", FALSE, &_data_->_inner_error_);
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp7_ = _data_->_tmp9_;
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_inner_error_ != NULL) {
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_data_->argv = (_vala_array_free (_data_->argv, _data_->argv_length1, (GDestroyNotify) g_free), NULL);
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_free0 (_data_->standard_output);
#line 4179 "util-app.c"
			goto __catch90_g_error;
		}
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->pool_path);
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->pool_path = _data_->_tmp7_;
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->argv = (_vala_array_free (_data_->argv, _data_->argv_length1, (GDestroyNotify) g_free), NULL);
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->standard_output);
#line 4190 "util-app.c"
	}
	goto __finally90;
	__catch90_g_error:
	{
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_inner_error_ = NULL;
#line 405 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp10_ = NULL;
#line 405 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp10_ = _data_->_error_;
#line 405 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp11_ = NULL;
#line 405 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp11_ = _data_->_tmp10_->message;
#line 405 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_debug ("util-app.vala:405: %s", _data_->_tmp11_);
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp12_ = NULL;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp12_ = _ ("Could not get 'gnome-boxes' storage pool information from libvirt. Mak" \
"e sure 'virsh -c qemu:///session pool-dumpxml gnome-boxes' is working.");
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp13_ = NULL;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp13_ = g_strdup (_data_->_tmp12_);
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->diagnosis);
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->diagnosis = _data_->_tmp13_;
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->result = FALSE;
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (_data_->_error_);
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->pool_path);
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_state_ == 0) {
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4231 "util-app.c"
		} else {
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4235 "util-app.c"
		}
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_object_unref (_data_->_async_result);
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 4241 "util-app.c"
	}
	__finally90:
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_inner_error_ != NULL) {
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->pool_path);
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_clear_error (&_data_->_inner_error_);
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 4254 "util-app.c"
	}
#line 410 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp14_ = NULL;
#line 410 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp14_ = _data_->pool_path;
#line 410 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp15_ = FALSE;
#line 410 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp15_ = g_file_test (_data_->_tmp14_, G_FILE_TEST_EXISTS);
#line 410 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (!_data_->_tmp15_) {
#line 411 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp16_ = NULL;
#line 411 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp16_ = _ ("%s is known to libvirt as GNOME Boxes's storage pool but this director" \
"y does not exist");
#line 411 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp17_ = NULL;
#line 411 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp17_ = _data_->pool_path;
#line 411 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp18_ = NULL;
#line 411 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp18_ = g_strdup_printf (_data_->_tmp16_, _data_->_tmp17_);
#line 411 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->diagnosis);
#line 411 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->diagnosis = _data_->_tmp18_;
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->result = FALSE;
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->pool_path);
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_state_ == 0) {
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4290 "util-app.c"
		} else {
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4294 "util-app.c"
		}
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_object_unref (_data_->_async_result);
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 4300 "util-app.c"
	}
#line 414 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp19_ = NULL;
#line 414 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp19_ = _data_->pool_path;
#line 414 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp20_ = FALSE;
#line 414 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp20_ = g_file_test (_data_->_tmp19_, G_FILE_TEST_IS_DIR);
#line 414 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (!_data_->_tmp20_) {
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp21_ = NULL;
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp21_ = _ ("%s is known to libvirt as GNOME Boxes's storage pool but is not a dire" \
"ctory");
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp22_ = NULL;
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp22_ = _data_->pool_path;
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp23_ = NULL;
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp23_ = g_strdup_printf (_data_->_tmp21_, _data_->_tmp22_);
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->diagnosis);
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->diagnosis = _data_->_tmp23_;
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->result = FALSE;
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->pool_path);
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_state_ == 0) {
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4336 "util-app.c"
		} else {
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4340 "util-app.c"
		}
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_object_unref (_data_->_async_result);
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 4346 "util-app.c"
	}
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp24_ = NULL;
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp24_ = _data_->pool_path;
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp25_ = 0;
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_tmp25_ = access (_data_->_tmp24_, (R_OK | W_OK) | X_OK);
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_tmp25_ != 0) {
#line 419 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp26_ = NULL;
#line 419 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp26_ = _ ("%s is known to libvirt as GNOME Boxes's storage pool but is not user-r" \
"eadable/writable");
#line 419 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp27_ = NULL;
#line 419 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp27_ = _data_->pool_path;
#line 419 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp28_ = NULL;
#line 419 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp28_ = g_strdup_printf (_data_->_tmp26_, _data_->_tmp27_);
#line 419 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->diagnosis);
#line 419 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->diagnosis = _data_->_tmp28_;
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->result = FALSE;
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->pool_path);
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_state_ == 0) {
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4382 "util-app.c"
		} else {
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4386 "util-app.c"
		}
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_object_unref (_data_->_async_result);
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 4392 "util-app.c"
	}
#line 423 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->result = TRUE;
#line 423 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (_data_->pool_path);
#line 423 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_state_ == 0) {
#line 423 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4402 "util-app.c"
	} else {
#line 423 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 4406 "util-app.c"
	}
#line 423 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_unref (_data_->_async_result);
#line 423 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (_data_->pool_path);
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_state_ == 0) {
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4418 "util-app.c"
	} else {
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 4422 "util-app.c"
	}
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_unref (_data_->_async_result);
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 4428 "util-app.c"
}


static guint8* _vala_array_dup5 (guint8* self, int length) {
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return g_memdup (self, length * sizeof (guint8));
#line 4435 "util-app.c"
}


GdkPixbuf* boxes_remove_alpha (GdkPixbuf* pixbuf) {
	GdkPixbuf* result = NULL;
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	static const guint8 ALPHA_TRESHOLD = (guint8) 50;
#line 4443 "util-app.c"
	gboolean _tmp0_ = FALSE;
	GdkPixbuf* _tmp1_ = NULL;
	gint _tmp2_ = 0;
	gboolean _tmp5_ = FALSE;
	GdkPixbuf* _tmp6_ = NULL;
	gint width = 0;
	GdkPixbuf* _tmp7_ = NULL;
	gint _tmp8_ = 0;
	gint height = 0;
	GdkPixbuf* _tmp9_ = NULL;
	gint _tmp10_ = 0;
	gint rowstride = 0;
	GdkPixbuf* _tmp11_ = NULL;
	gint _tmp12_ = 0;
	guint8* orig_pixels = NULL;
	GdkPixbuf* _tmp13_ = NULL;
	guint8* _tmp14_ = NULL;
	gint orig_pixels_length1 = 0;
	gint _orig_pixels_size_ = 0;
	guint8* pixels = NULL;
	gint _tmp15_ = 0;
	gint _tmp16_ = 0;
	guint8* _tmp17_ = NULL;
	gint pixels_length1 = 0;
	gint _pixels_size_ = 0;
	guint8* _tmp65_ = NULL;
	gint _tmp65__length1 = 0;
	guint8* _tmp66_ = NULL;
	gint _tmp66__length1 = 0;
	GdkPixbuf* _tmp67_ = NULL;
	GdkColorspace _tmp68_ = 0;
	gint _tmp69_ = 0;
	gint _tmp70_ = 0;
	gint _tmp71_ = 0;
	GdkPixbuf* _tmp72_ = NULL;
#line 428 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (pixbuf != NULL, NULL);
#line 431 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = pixbuf;
#line 431 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = gdk_pixbuf_get_n_channels (_tmp1_);
#line 431 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp2_ == 4) {
#line 4487 "util-app.c"
		GdkPixbuf* _tmp3_ = NULL;
		gint _tmp4_ = 0;
#line 431 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp3_ = pixbuf;
#line 431 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp4_ = gdk_pixbuf_get_bits_per_sample (_tmp3_);
#line 431 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp0_ = _tmp4_ == 8;
#line 4496 "util-app.c"
	} else {
#line 431 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp0_ = FALSE;
#line 4500 "util-app.c"
	}
#line 431 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = _tmp0_;
#line 431 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp6_ = pixbuf;
#line 431 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (_tmp5_, _tmp6_);
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp7_ = pixbuf;
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp8_ = gdk_pixbuf_get_width (_tmp7_);
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	width = _tmp8_;
#line 434 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp9_ = pixbuf;
#line 434 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp10_ = gdk_pixbuf_get_height (_tmp9_);
#line 434 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	height = _tmp10_;
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp11_ = pixbuf;
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp12_ = gdk_pixbuf_get_rowstride (_tmp11_);
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	rowstride = _tmp12_;
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp13_ = pixbuf;
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp14_ = gdk_pixbuf_get_pixels (_tmp13_);
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	orig_pixels = _tmp14_;
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	orig_pixels_length1 = -1;
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_orig_pixels_size_ = orig_pixels_length1;
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp15_ = rowstride;
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp16_ = height;
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp17_ = g_new0 (guint8, _tmp15_ * _tmp16_);
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	pixels = _tmp17_;
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	pixels_length1 = _tmp15_ * _tmp16_;
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_pixels_size_ = pixels_length1;
#line 4548 "util-app.c"
	{
		gint i = 0;
#line 439 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		i = 0;
#line 4553 "util-app.c"
		{
			gboolean _tmp18_ = FALSE;
#line 439 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp18_ = TRUE;
#line 439 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			while (TRUE) {
#line 4560 "util-app.c"
				gboolean _tmp19_ = FALSE;
				gint _tmp21_ = 0;
				gint _tmp22_ = 0;
#line 439 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp19_ = _tmp18_;
#line 439 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				if (!_tmp19_) {
#line 4568 "util-app.c"
					gint _tmp20_ = 0;
#line 439 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					_tmp20_ = i;
#line 439 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					i = _tmp20_ + 1;
#line 4574 "util-app.c"
				}
#line 439 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp18_ = FALSE;
#line 439 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp21_ = i;
#line 439 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp22_ = height;
#line 439 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				if (!(_tmp21_ < _tmp22_)) {
#line 439 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					break;
#line 4586 "util-app.c"
				}
				{
					gint j = 0;
					gint k = 0;
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					j = 0;
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					k = 0;
#line 4595 "util-app.c"
					{
						gboolean _tmp23_ = FALSE;
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
						_tmp23_ = TRUE;
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
						while (TRUE) {
#line 4602 "util-app.c"
							gboolean _tmp24_ = FALSE;
							gint _tmp27_ = 0;
							gint _tmp28_ = 0;
							gint orig_index = 0;
							gint _tmp29_ = 0;
							gint _tmp30_ = 0;
							gint _tmp31_ = 0;
							gint index = 0;
							gint _tmp32_ = 0;
							gint _tmp33_ = 0;
							gint _tmp34_ = 0;
							guint8* _tmp35_ = NULL;
							gint _tmp35__length1 = 0;
							gint _tmp36_ = 0;
							guint8 _tmp37_ = 0U;
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp24_ = _tmp23_;
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							if (!_tmp24_) {
#line 4622 "util-app.c"
								gint _tmp25_ = 0;
								gint _tmp26_ = 0;
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp25_ = j;
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								j = _tmp25_ + 4;
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp26_ = k;
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								k = _tmp26_ + 3;
#line 4633 "util-app.c"
							}
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp23_ = FALSE;
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp27_ = j;
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp28_ = width;
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							if (!(_tmp27_ < (_tmp28_ * 4))) {
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								break;
#line 4645 "util-app.c"
							}
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp29_ = rowstride;
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp30_ = i;
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp31_ = j;
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							orig_index = (_tmp29_ * _tmp30_) + _tmp31_;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp32_ = rowstride;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp33_ = i;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp34_ = k;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							index = (_tmp32_ * _tmp33_) + _tmp34_;
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp35_ = orig_pixels;
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp35__length1 = orig_pixels_length1;
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp36_ = orig_index;
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							_tmp37_ = _tmp35_[_tmp36_ + 3];
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							if (_tmp37_ < ALPHA_TRESHOLD) {
#line 4673 "util-app.c"
								guint8* _tmp38_ = NULL;
								gint _tmp38__length1 = 0;
								gint _tmp39_ = 0;
								guint8 _tmp40_ = 0U;
								guint8* _tmp41_ = NULL;
								gint _tmp41__length1 = 0;
								gint _tmp42_ = 0;
								guint8 _tmp43_ = 0U;
								guint8* _tmp44_ = NULL;
								gint _tmp44__length1 = 0;
								gint _tmp45_ = 0;
								guint8 _tmp46_ = 0U;
#line 445 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp38_ = pixels;
#line 445 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp38__length1 = pixels_length1;
#line 445 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp39_ = index;
#line 445 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp38_[_tmp39_] = (guint8) 0xFF;
#line 445 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp40_ = _tmp38_[_tmp39_];
#line 446 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp41_ = pixels;
#line 446 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp41__length1 = pixels_length1;
#line 446 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp42_ = index;
#line 446 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp41_[_tmp42_ + 1] = (guint8) 0xFF;
#line 446 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp43_ = _tmp41_[_tmp42_ + 1];
#line 447 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp44_ = pixels;
#line 447 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp44__length1 = pixels_length1;
#line 447 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp45_ = index;
#line 447 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp44_[_tmp45_ + 2] = (guint8) 0xFF;
#line 447 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp46_ = _tmp44_[_tmp45_ + 2];
#line 4716 "util-app.c"
							} else {
								guint8* _tmp47_ = NULL;
								gint _tmp47__length1 = 0;
								gint _tmp48_ = 0;
								guint8* _tmp49_ = NULL;
								gint _tmp49__length1 = 0;
								gint _tmp50_ = 0;
								guint8 _tmp51_ = 0U;
								guint8 _tmp52_ = 0U;
								guint8* _tmp53_ = NULL;
								gint _tmp53__length1 = 0;
								gint _tmp54_ = 0;
								guint8* _tmp55_ = NULL;
								gint _tmp55__length1 = 0;
								gint _tmp56_ = 0;
								guint8 _tmp57_ = 0U;
								guint8 _tmp58_ = 0U;
								guint8* _tmp59_ = NULL;
								gint _tmp59__length1 = 0;
								gint _tmp60_ = 0;
								guint8* _tmp61_ = NULL;
								gint _tmp61__length1 = 0;
								gint _tmp62_ = 0;
								guint8 _tmp63_ = 0U;
								guint8 _tmp64_ = 0U;
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp47_ = pixels;
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp47__length1 = pixels_length1;
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp48_ = index;
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp49_ = orig_pixels;
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp49__length1 = orig_pixels_length1;
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp50_ = orig_index;
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp51_ = _tmp49_[_tmp50_];
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp47_[_tmp48_] = _tmp51_;
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp52_ = _tmp47_[_tmp48_];
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp53_ = pixels;
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp53__length1 = pixels_length1;
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp54_ = index;
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp55_ = orig_pixels;
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp55__length1 = orig_pixels_length1;
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp56_ = orig_index;
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp57_ = _tmp55_[_tmp56_ + 1];
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp53_[_tmp54_ + 1] = _tmp57_;
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp58_ = _tmp53_[_tmp54_ + 1];
#line 451 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp59_ = pixels;
#line 451 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp59__length1 = pixels_length1;
#line 451 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp60_ = index;
#line 451 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp61_ = orig_pixels;
#line 451 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp61__length1 = orig_pixels_length1;
#line 451 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp62_ = orig_index;
#line 451 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp63_ = _tmp61_[_tmp62_ + 2];
#line 451 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp59_[_tmp60_ + 2] = _tmp63_;
#line 451 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
								_tmp64_ = _tmp59_[_tmp60_ + 2];
#line 4796 "util-app.c"
							}
						}
					}
				}
			}
		}
	}
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp65_ = pixels;
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp65__length1 = pixels_length1;
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp66_ = (_tmp65_ != NULL) ? _vala_array_dup5 (_tmp65_, _tmp65__length1) : ((gpointer) _tmp65_);
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp66__length1 = _tmp65__length1;
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp67_ = pixbuf;
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp68_ = gdk_pixbuf_get_colorspace (_tmp67_);
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp69_ = width;
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp70_ = height;
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp71_ = rowstride;
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp72_ = gdk_pixbuf_new_from_data (_tmp66_, _tmp68_, FALSE, 8, _tmp69_, _tmp70_, _tmp71_, (GdkPixbufDestroyNotify) NULL, NULL);
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = _tmp72_;
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	pixels = (g_free (pixels), NULL);
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 4830 "util-app.c"
}


static Block65Data* block65_data_ref (Block65Data* _data65_) {
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_atomic_int_inc (&_data65_->_ref_count_);
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return _data65_;
#line 4839 "util-app.c"
}


static void block65_data_unref (void * _userdata_) {
	Block65Data* _data65_;
	_data65_ = (Block65Data*) _userdata_;
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (g_atomic_int_dec_and_test (&_data65_->_ref_count_)) {
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (_data65_->widget);
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_slice_free (Block65Data, _data65_);
#line 4852 "util-app.c"
	}
}


static gboolean __lambda186_ (Block65Data* _data65_, cairo_t* cr) {
	gboolean result = FALSE;
	GtkStyleContext* context = NULL;
	GtkWidget* _tmp0_ = NULL;
	GtkStyleContext* _tmp1_ = NULL;
	GtkStyleContext* _tmp2_ = NULL;
	GtkAllocation allocation = {0};
	GtkWidget* _tmp3_ = NULL;
	GtkAllocation _tmp4_ = {0};
	cairo_t* _tmp5_ = NULL;
	GtkAllocation _tmp6_ = {0};
	gint _tmp7_ = 0;
	GtkAllocation _tmp8_ = {0};
	gint _tmp9_ = 0;
	cairo_t* _tmp10_ = NULL;
	GtkAllocation _tmp11_ = {0};
	gint _tmp12_ = 0;
	GtkAllocation _tmp13_ = {0};
	gint _tmp14_ = 0;
#line 467 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (cr != NULL, FALSE);
#line 468 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = _data65_->widget;
#line 468 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = gtk_widget_get_style_context (_tmp0_);
#line 468 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 468 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	context = _tmp2_;
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = _data65_->widget;
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	gtk_widget_get_allocation (_tmp3_, &_tmp4_);
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	allocation = _tmp4_;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = cr;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp6_ = allocation;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp7_ = _tmp6_.width;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp8_ = allocation;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp9_ = _tmp8_.height;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	gtk_render_background (context, _tmp5_, (gdouble) 0, (gdouble) 0, (gdouble) _tmp7_, (gdouble) _tmp9_);
#line 474 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp10_ = cr;
#line 474 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp11_ = allocation;
#line 474 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp12_ = _tmp11_.width;
#line 474 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp13_ = allocation;
#line 474 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp14_ = _tmp13_.height;
#line 474 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	gtk_render_frame (context, _tmp10_, (gdouble) 0, (gdouble) 0, (gdouble) _tmp12_, (gdouble) _tmp14_);
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = FALSE;
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (context);
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 4922 "util-app.c"
}


static gboolean ___lambda186__gtk_widget_draw (GtkWidget* _sender, cairo_t* cr, gpointer self) {
	gboolean result;
	result = __lambda186_ (self, cr);
#line 467 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 4931 "util-app.c"
}


void boxes_draw_as_css_box (GtkWidget* widget) {
	Block65Data* _data65_;
	GtkWidget* _tmp0_ = NULL;
	GtkWidget* _tmp1_ = NULL;
	GtkWidget* _tmp2_ = NULL;
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_if_fail (widget != NULL);
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data65_ = g_slice_new0 (Block65Data);
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data65_->_ref_count_ = 1;
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = widget;
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (_data65_->widget);
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data65_->widget = _tmp1_;
#line 467 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = _data65_->widget;
#line 467 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_signal_connect_data (_tmp2_, "draw", (GCallback) ___lambda186__gtk_widget_draw, block65_data_ref (_data65_), (GClosureNotify) block65_data_unref, 0);
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	block65_data_unref (_data65_);
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data65_ = NULL;
#line 4962 "util-app.c"
}


static void boxes_copy_file_data_free (gpointer _data) {
	BoxesCopyFileData* _data_;
	_data_ = _data;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->src_file);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->dest_file);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->cancellable);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesCopyFileData, _data_);
#line 4977 "util-app.c"
}


void boxes_copy_file (GFile* src_file, GFile* dest_file, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesCopyFileData* _data_;
	GFile* _tmp0_ = NULL;
	GFile* _tmp1_ = NULL;
	GFile* _tmp2_ = NULL;
	GFile* _tmp3_ = NULL;
	GCancellable* _tmp4_ = NULL;
	GCancellable* _tmp5_ = NULL;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesCopyFileData);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_copy_file);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_copy_file_data_free);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = src_file;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->src_file);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->src_file = _tmp1_;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = dest_file;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->dest_file);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->dest_file = _tmp3_;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp4_ = cancellable;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp5_ = _g_object_ref0 (_tmp4_);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->cancellable);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->cancellable = _tmp5_;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_copy_file_co (_data_);
#line 5021 "util-app.c"
}


void boxes_copy_file_finish (GAsyncResult* _res_, GError** error) {
	BoxesCopyFileData* _data_;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 5031 "util-app.c"
	}
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 5035 "util-app.c"
}


static void boxes_copy_file_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesCopyFileData* _data_;
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_ = _user_data_;
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_source_object_ = source_object;
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_data_->_res_ = _res_;
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	boxes_copy_file_co (_data_);
#line 5049 "util-app.c"
}


static gboolean boxes_copy_file_co (BoxesCopyFileData* _data_) {
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	switch (_data_->_state_) {
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 0:
#line 5058 "util-app.c"
		goto _state_0;
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		case 1:
#line 5062 "util-app.c"
		goto _state_1;
		default:
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_assert_not_reached ();
#line 5067 "util-app.c"
	}
	_state_0:
	{
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp0_ = NULL;
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp0_ = _data_->src_file;
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp1_ = NULL;
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp1_ = g_file_get_path (_data_->_tmp0_);
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_ = NULL;
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp2_ = _data_->_tmp1_;
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3_ = NULL;
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp3_ = _data_->dest_file;
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_ = NULL;
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp4_ = g_file_get_path (_data_->_tmp3_);
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp5_ = NULL;
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp5_ = _data_->_tmp4_;
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_debug ("util-app.vala:483: Copying '%s' to '%s'..", _data_->_tmp2_, _data_->_tmp5_);
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->_tmp5_);
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->_tmp2_);
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_ = NULL;
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp6_ = _data_->src_file;
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp7_ = NULL;
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp7_ = _data_->dest_file;
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp8_ = NULL;
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp8_ = _data_->cancellable;
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_state_ = 1;
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_file_copy_async (_data_->_tmp6_, _data_->_tmp7_, 0, G_PRIORITY_DEFAULT, _data_->_tmp8_, NULL, NULL, boxes_copy_file_ready, _data_);
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 5119 "util-app.c"
		_state_1:
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_file_copy_finish (_data_->_tmp6_, _data_->_res_, &_data_->_inner_error_);
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_inner_error_ != NULL) {
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (g_error_matches (_data_->_inner_error_, G_IO_ERROR, G_IO_ERROR_EXISTS)) {
#line 5127 "util-app.c"
				goto __catch91_g_io_error_exists;
			}
			goto __finally91;
		}
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp9_ = NULL;
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp9_ = _data_->src_file;
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp10_ = NULL;
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp10_ = g_file_get_path (_data_->_tmp9_);
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp11_ = NULL;
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp11_ = _data_->_tmp10_;
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp12_ = NULL;
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp12_ = _data_->dest_file;
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp13_ = NULL;
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp13_ = g_file_get_path (_data_->_tmp12_);
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp14_ = NULL;
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_tmp14_ = _data_->_tmp13_;
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_debug ("util-app.vala:485: Copied '%s' to '%s'.", _data_->_tmp11_, _data_->_tmp14_);
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->_tmp14_);
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (_data_->_tmp11_);
#line 5162 "util-app.c"
	}
	goto __finally91;
	__catch91_g_io_error_exists:
	{
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_data_->_inner_error_ = NULL;
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (_data_->_error_);
#line 5173 "util-app.c"
	}
	__finally91:
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_inner_error_ != NULL) {
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_error_free (_data_->_inner_error_);
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_data_->_state_ == 0) {
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5186 "util-app.c"
		} else {
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 5190 "util-app.c"
		}
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_object_unref (_data_->_async_result);
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return FALSE;
#line 5196 "util-app.c"
	}
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_data_->_state_ == 0) {
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5202 "util-app.c"
	} else {
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 5206 "util-app.c"
	}
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_object_unref (_data_->_async_result);
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return FALSE;
#line 5212 "util-app.c"
}


GType boxes_cpu_arch_compatibility_get_type (void) {
	static volatile gsize boxes_cpu_arch_compatibility_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_cpu_arch_compatibility_type_id__volatile)) {
		static const GEnumValue values[] = {{BOXES_CPU_ARCH_COMPATIBILITY_INCOMPATIBLE, "BOXES_CPU_ARCH_COMPATIBILITY_INCOMPATIBLE", "incompatible"}, {BOXES_CPU_ARCH_COMPATIBILITY_IDENTICAL, "BOXES_CPU_ARCH_COMPATIBILITY_IDENTICAL", "identical"}, {BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE, "BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE", "compatible"}, {BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE_DIFF_WORDSIZE, "BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE_DIFF_WORDSIZE", "compatible-diff-wordsize"}, {0, NULL, NULL}};
		GType boxes_cpu_arch_compatibility_type_id;
		boxes_cpu_arch_compatibility_type_id = g_enum_register_static ("BoxesCPUArchCompatibility", values);
		g_once_init_leave (&boxes_cpu_arch_compatibility_type_id__volatile, boxes_cpu_arch_compatibility_type_id);
	}
	return boxes_cpu_arch_compatibility_type_id__volatile;
}


BoxesCPUArchCompatibility boxes_compare_cpu_architectures (const gchar* arch1, const gchar* arch2) {
	BoxesCPUArchCompatibility result = 0;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	GQuark _tmp3_ = 0U;
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	static GQuark _tmp2_label0 = 0;
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	static GQuark _tmp2_label1 = 0;
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	static GQuark _tmp2_label2 = 0;
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	static GQuark _tmp2_label3 = 0;
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	static GQuark _tmp2_label4 = 0;
#line 499 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (arch1 != NULL, 0);
#line 499 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (arch2 != NULL, 0);
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = arch2;
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = _tmp0_;
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = (NULL == _tmp1_) ? 0 : g_quark_from_string (_tmp1_);
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp3_ == ((0 != _tmp2_label0) ? _tmp2_label0 : (_tmp2_label0 = g_quark_from_static_string ("i386")))) {
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		switch (0) {
#line 5257 "util-app.c"
			default:
			{
				const gchar* _tmp4_ = NULL;
				const gchar* _tmp5_ = NULL;
				GQuark _tmp7_ = 0U;
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp6_label0 = 0;
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp6_label1 = 0;
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp6_label2 = 0;
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp6_label3 = 0;
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp6_label4 = 0;
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp4_ = arch1;
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp5_ = _tmp4_;
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp7_ = (NULL == _tmp5_) ? 0 : g_quark_from_string (_tmp5_);
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				if (_tmp7_ == ((0 != _tmp6_label0) ? _tmp6_label0 : (_tmp6_label0 = g_quark_from_static_string ("i386")))) {
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 5283 "util-app.c"
						default:
						{
#line 504 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_IDENTICAL;
#line 504 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 5290 "util-app.c"
						}
					}
				} else if (((_tmp7_ == ((0 != _tmp6_label1) ? _tmp6_label1 : (_tmp6_label1 = g_quark_from_static_string ("i486")))) || (_tmp7_ == ((0 != _tmp6_label2) ? _tmp6_label2 : (_tmp6_label2 = g_quark_from_static_string ("i586"))))) || (_tmp7_ == ((0 != _tmp6_label3) ? _tmp6_label3 : (_tmp6_label3 = g_quark_from_static_string ("i686"))))) {
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 5296 "util-app.c"
						default:
						{
#line 508 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE;
#line 508 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 5303 "util-app.c"
						}
					}
				} else if (_tmp7_ == ((0 != _tmp6_label4) ? _tmp6_label4 : (_tmp6_label4 = g_quark_from_static_string ("x86_64")))) {
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 5309 "util-app.c"
						default:
						{
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE_DIFF_WORDSIZE;
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 5316 "util-app.c"
						}
					}
				} else {
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 5322 "util-app.c"
						default:
						{
#line 512 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_INCOMPATIBLE;
#line 512 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 5329 "util-app.c"
						}
					}
				}
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label1) ? _tmp2_label1 : (_tmp2_label1 = g_quark_from_static_string ("i486")))) {
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		switch (0) {
#line 5338 "util-app.c"
			default:
			{
				const gchar* _tmp8_ = NULL;
				const gchar* _tmp9_ = NULL;
				GQuark _tmp11_ = 0U;
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp10_label0 = 0;
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp10_label1 = 0;
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp10_label2 = 0;
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp10_label3 = 0;
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp8_ = arch1;
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp9_ = _tmp8_;
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp11_ = (NULL == _tmp9_) ? 0 : g_quark_from_string (_tmp9_);
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				if (_tmp11_ == ((0 != _tmp10_label0) ? _tmp10_label0 : (_tmp10_label0 = g_quark_from_static_string ("i486")))) {
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 5362 "util-app.c"
						default:
						{
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_IDENTICAL;
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 5369 "util-app.c"
						}
					}
				} else if ((_tmp11_ == ((0 != _tmp10_label1) ? _tmp10_label1 : (_tmp10_label1 = g_quark_from_static_string ("i586")))) || (_tmp11_ == ((0 != _tmp10_label2) ? _tmp10_label2 : (_tmp10_label2 = g_quark_from_static_string ("i686"))))) {
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 5375 "util-app.c"
						default:
						{
#line 520 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE;
#line 520 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 5382 "util-app.c"
						}
					}
				} else if (_tmp11_ == ((0 != _tmp10_label3) ? _tmp10_label3 : (_tmp10_label3 = g_quark_from_static_string ("x86_64")))) {
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 5388 "util-app.c"
						default:
						{
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE_DIFF_WORDSIZE;
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 5395 "util-app.c"
						}
					}
				} else {
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 5401 "util-app.c"
						default:
						{
#line 524 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_INCOMPATIBLE;
#line 524 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 5408 "util-app.c"
						}
					}
				}
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label2) ? _tmp2_label2 : (_tmp2_label2 = g_quark_from_static_string ("i586")))) {
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		switch (0) {
#line 5417 "util-app.c"
			default:
			{
				const gchar* _tmp12_ = NULL;
				const gchar* _tmp13_ = NULL;
				GQuark _tmp15_ = 0U;
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp14_label0 = 0;
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp14_label1 = 0;
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp14_label2 = 0;
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp12_ = arch1;
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp13_ = _tmp12_;
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp15_ = (NULL == _tmp13_) ? 0 : g_quark_from_string (_tmp13_);
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				if (_tmp15_ == ((0 != _tmp14_label0) ? _tmp14_label0 : (_tmp14_label0 = g_quark_from_static_string ("i586")))) {
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 5439 "util-app.c"
						default:
						{
#line 529 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_IDENTICAL;
#line 529 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 5446 "util-app.c"
						}
					}
				} else if (_tmp15_ == ((0 != _tmp14_label1) ? _tmp14_label1 : (_tmp14_label1 = g_quark_from_static_string ("i686")))) {
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 5452 "util-app.c"
						default:
						{
#line 531 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE;
#line 531 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 5459 "util-app.c"
						}
					}
				} else if (_tmp15_ == ((0 != _tmp14_label2) ? _tmp14_label2 : (_tmp14_label2 = g_quark_from_static_string ("x86_64")))) {
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 5465 "util-app.c"
						default:
						{
#line 533 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE_DIFF_WORDSIZE;
#line 533 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 5472 "util-app.c"
						}
					}
				} else {
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 5478 "util-app.c"
						default:
						{
#line 535 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_INCOMPATIBLE;
#line 535 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 5485 "util-app.c"
						}
					}
				}
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label3) ? _tmp2_label3 : (_tmp2_label3 = g_quark_from_static_string ("i686")))) {
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		switch (0) {
#line 5494 "util-app.c"
			default:
			{
				const gchar* _tmp16_ = NULL;
				const gchar* _tmp17_ = NULL;
				GQuark _tmp19_ = 0U;
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp18_label0 = 0;
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp18_label1 = 0;
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp16_ = arch1;
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp17_ = _tmp16_;
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp19_ = (NULL == _tmp17_) ? 0 : g_quark_from_string (_tmp17_);
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				if (_tmp19_ == ((0 != _tmp18_label0) ? _tmp18_label0 : (_tmp18_label0 = g_quark_from_static_string ("i686")))) {
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 5514 "util-app.c"
						default:
						{
#line 540 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_IDENTICAL;
#line 540 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 5521 "util-app.c"
						}
					}
				} else if (_tmp19_ == ((0 != _tmp18_label1) ? _tmp18_label1 : (_tmp18_label1 = g_quark_from_static_string ("x86_64")))) {
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 5527 "util-app.c"
						default:
						{
#line 542 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE_DIFF_WORDSIZE;
#line 542 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 5534 "util-app.c"
						}
					}
				} else {
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 5540 "util-app.c"
						default:
						{
#line 544 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_INCOMPATIBLE;
#line 544 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 5547 "util-app.c"
						}
					}
				}
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label4) ? _tmp2_label4 : (_tmp2_label4 = g_quark_from_static_string ("x86_64")))) {
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		switch (0) {
#line 5556 "util-app.c"
			default:
			{
				const gchar* _tmp20_ = NULL;
				const gchar* _tmp21_ = NULL;
				GQuark _tmp23_ = 0U;
#line 547 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				static GQuark _tmp22_label0 = 0;
#line 547 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp20_ = arch1;
#line 547 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp21_ = _tmp20_;
#line 547 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp23_ = (NULL == _tmp21_) ? 0 : g_quark_from_string (_tmp21_);
#line 547 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				if (_tmp23_ == ((0 != _tmp22_label0) ? _tmp22_label0 : (_tmp22_label0 = g_quark_from_static_string ("x86_64")))) {
#line 547 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 5574 "util-app.c"
						default:
						{
#line 549 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_IDENTICAL;
#line 549 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 5581 "util-app.c"
						}
					}
				} else {
#line 547 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 5587 "util-app.c"
						default:
						{
#line 551 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_INCOMPATIBLE;
#line 551 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 5594 "util-app.c"
						}
					}
				}
			}
		}
	} else if (_tmp3_ == g_quark_from_string (OSINFO_ARCHITECTURE_ALL)) {
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		switch (0) {
#line 5603 "util-app.c"
			default:
			{
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				result = BOXES_CPU_ARCH_COMPATIBILITY_COMPATIBLE;
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				return result;
#line 5610 "util-app.c"
			}
		}
	} else {
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		switch (0) {
#line 5616 "util-app.c"
			default:
			{
				const gchar* _tmp24_ = NULL;
				const gchar* _tmp25_ = NULL;
				GQuark _tmp27_ = 0U;
#line 556 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp24_ = arch1;
#line 556 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp25_ = _tmp24_;
#line 556 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				_tmp27_ = (NULL == _tmp25_) ? 0 : g_quark_from_string (_tmp25_);
#line 556 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
				if (_tmp27_ == g_quark_from_string (OSINFO_ARCHITECTURE_ALL)) {
#line 556 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 5632 "util-app.c"
						default:
						{
#line 558 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_IDENTICAL;
#line 558 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 5639 "util-app.c"
						}
					}
				} else {
#line 556 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
					switch (0) {
#line 5645 "util-app.c"
						default:
						{
#line 560 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							result = BOXES_CPU_ARCH_COMPATIBILITY_INCOMPATIBLE;
#line 560 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
							return result;
#line 5652 "util-app.c"
						}
					}
				}
			}
		}
	}
}


gchar* boxes_fdo_timedate1_get_timezone (BoxesFdotimedate1* self) {
#line 567 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 567 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return BOXES_FDO_TIMEDATE1_GET_INTERFACE (self)->get_timezone (self);
#line 5667 "util-app.c"
}


void boxes_fdo_timedate1_set_timezone (BoxesFdotimedate1* self, const gchar* value) {
#line 567 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_if_fail (self != NULL);
#line 567 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	BOXES_FDO_TIMEDATE1_GET_INTERFACE (self)->set_timezone (self, value);
#line 5676 "util-app.c"
}


static void boxes_fdo_timedate1_base_init (BoxesFdotimedate1Iface * iface) {
#line 566 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	static gboolean initialized = FALSE;
#line 566 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (!initialized) {
#line 566 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		initialized = TRUE;
#line 5687 "util-app.c"
	}
}


GType boxes_fdo_timedate1_get_type (void) {
	static volatile gsize boxes_fdo_timedate1_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_fdo_timedate1_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesFdotimedate1Iface), (GBaseInitFunc) boxes_fdo_timedate1_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType boxes_fdo_timedate1_type_id;
		boxes_fdo_timedate1_type_id = g_type_register_static (G_TYPE_INTERFACE, "BoxesFdotimedate1", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (boxes_fdo_timedate1_type_id, G_TYPE_OBJECT);
		g_type_set_qdata (boxes_fdo_timedate1_type_id, g_quark_from_static_string ("vala-dbus-proxy-type"), (void*) boxes_fdo_timedate1_proxy_get_type);
		g_type_set_qdata (boxes_fdo_timedate1_type_id, g_quark_from_static_string ("vala-dbus-interface-name"), "org.freedesktop.timedate1");
		g_type_set_qdata (boxes_fdo_timedate1_type_id, g_quark_from_static_string ("vala-dbus-register-object"), (void*) boxes_fdo_timedate1_register_object);
		g_once_init_leave (&boxes_fdo_timedate1_type_id__volatile, boxes_fdo_timedate1_type_id);
	}
	return boxes_fdo_timedate1_type_id__volatile;
}


G_DEFINE_TYPE_EXTENDED (BoxesFdotimedate1Proxy, boxes_fdo_timedate1_proxy, G_TYPE_DBUS_PROXY, 0, G_IMPLEMENT_INTERFACE (BOXES_FDO_TYPE_TIMEDATE1, boxes_fdo_timedate1_proxy_boxes_fdo_timedate1_interface_init) )
static void boxes_fdo_timedate1_proxy_class_init (BoxesFdotimedate1ProxyClass* klass) {
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	G_DBUS_PROXY_CLASS (klass)->g_signal = boxes_fdo_timedate1_proxy_g_signal;
#line 5712 "util-app.c"
}


static void boxes_fdo_timedate1_proxy_g_signal (GDBusProxy* proxy, const gchar* sender_name, const gchar* signal_name, GVariant* parameters) {
}


static void boxes_fdo_timedate1_proxy_init (BoxesFdotimedate1Proxy* self) {
}


static gchar* boxes_fdo_timedate1_dbus_proxy_get_timezone (BoxesFdotimedate1* self) {
	GVariant *_inner_reply;
	gchar* _result;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "Timezone");
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (!_inner_reply) {
#line 5731 "util-app.c"
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.freedesktop.timedate1"));
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Timezone"));
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_arguments = g_variant_builder_end (&_arguments_builder);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (!_reply) {
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			return NULL;
#line 5749 "util-app.c"
		}
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_variant_get (_reply, "(v)", &_inner_reply);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_variant_unref (_reply);
#line 5755 "util-app.c"
	}
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_result = g_variant_dup_string (_inner_reply, NULL);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_variant_unref (_inner_reply);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return _result;
#line 5763 "util-app.c"
}


static void boxes_fdo_timedate1_dbus_proxy_set_timezone (BoxesFdotimedate1* self, const gchar* value) {
	GVariant *_arguments;
	GVariant *_reply;
	GVariantBuilder _arguments_builder;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.freedesktop.timedate1"));
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Timezone"));
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_variant_builder_open (&_arguments_builder, G_VARIANT_TYPE_VARIANT);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (value));
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_variant_builder_close (&_arguments_builder);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_arguments = g_variant_builder_end (&_arguments_builder);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Set", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (!_reply) {
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 5791 "util-app.c"
	}
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_variant_unref (_reply);
#line 5795 "util-app.c"
}


static void boxes_fdo_timedate1_proxy_boxes_fdo_timedate1_interface_init (BoxesFdotimedate1Iface* iface) {
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	iface->get_timezone = boxes_fdo_timedate1_dbus_proxy_get_timezone;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	iface->set_timezone = boxes_fdo_timedate1_dbus_proxy_set_timezone;
#line 5804 "util-app.c"
}


static void boxes_fdo_timedate1_dbus_interface_method_call (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* method_name, GVariant* parameters, GDBusMethodInvocation* invocation, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (invocation);
#line 5815 "util-app.c"
}


static GVariant* _dbus_boxes_fdo_timedate1_get_timezone (BoxesFdotimedate1* self) {
	gchar* result;
	GVariant* _reply;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = boxes_fdo_timedate1_get_timezone (self);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_reply = g_variant_new_string (result);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (result);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return _reply;
#line 5830 "util-app.c"
}


static GVariant* boxes_fdo_timedate1_dbus_interface_get_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GError** error, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (strcmp (property_name, "Timezone") == 0) {
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return _dbus_boxes_fdo_timedate1_get_timezone (object);
#line 5843 "util-app.c"
	}
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return NULL;
#line 5847 "util-app.c"
}


static void _dbus_boxes_fdo_timedate1_set_timezone (BoxesFdotimedate1* self, GVariant* _value) {
	gchar* value = NULL;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	value = g_variant_dup_string (_value, NULL);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_fdo_timedate1_set_timezone (self, value);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (value);
#line 5859 "util-app.c"
}


static gboolean boxes_fdo_timedate1_dbus_interface_set_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GVariant* value, GError** error, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (strcmp (property_name, "Timezone") == 0) {
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_dbus_boxes_fdo_timedate1_set_timezone (object, value);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return TRUE;
#line 5874 "util-app.c"
	}
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return FALSE;
#line 5878 "util-app.c"
}


guint boxes_fdo_timedate1_register_object (gpointer object, GDBusConnection* connection, const gchar* path, GError** error) {
	guint result;
	gpointer *data;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	data = g_new (gpointer, 3);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	data[0] = g_object_ref (object);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	data[1] = g_object_ref (connection);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	data[2] = g_strdup (path);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = g_dbus_connection_register_object (connection, path, (GDBusInterfaceInfo *) (&_boxes_fdo_timedate1_dbus_interface_info), &_boxes_fdo_timedate1_dbus_interface_vtable, data, _boxes_fdo_timedate1_unregister_object, error);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (!result) {
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return 0;
#line 5899 "util-app.c"
	}
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 5903 "util-app.c"
}


static void _boxes_fdo_timedate1_unregister_object (gpointer user_data) {
	gpointer* data;
	data = user_data;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (data[0]);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (data[1]);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_free (data[2]);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_free (data);
#line 5918 "util-app.c"
}


gchar* boxes_get_timezone (void) {
	gchar* result = NULL;
	GError * _inner_error_ = NULL;
	{
		gchar* _tmp0_ = NULL;
		gchar* _tmp1_ = NULL;
#line 572 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp1_ = boxes_get_timezone_from_systemd (&_inner_error_);
#line 572 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp0_ = _tmp1_;
#line 572 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		if (_inner_error_ != NULL) {
#line 5934 "util-app.c"
			goto __catch92_g_error;
		}
#line 572 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		result = _tmp0_;
#line 572 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return result;
#line 5941 "util-app.c"
	}
	goto __finally92;
	__catch92_g_error:
	{
		GError* e = NULL;
		GError* _tmp2_ = NULL;
		const gchar* _tmp3_ = NULL;
#line 571 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		e = _inner_error_;
#line 571 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_inner_error_ = NULL;
#line 575 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp2_ = e;
#line 575 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp3_ = _tmp2_->message;
#line 575 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_debug ("util-app.vala:575: Failed to get timezone from systemd: %s", _tmp3_);
#line 5959 "util-app.c"
		{
			gchar* _tmp4_ = NULL;
			gchar* _tmp5_ = NULL;
#line 577 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp5_ = boxes_get_timezone_from_linux (&_inner_error_);
#line 577 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp4_ = _tmp5_;
#line 577 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			if (_inner_error_ != NULL) {
#line 5969 "util-app.c"
				goto __catch93_g_error;
			}
#line 577 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			result = _tmp4_;
#line 577 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_error_free0 (e);
#line 577 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			return result;
#line 5978 "util-app.c"
		}
		goto __finally93;
		__catch93_g_error:
		{
			GError* e = NULL;
			GError* _tmp6_ = NULL;
			const gchar* _tmp7_ = NULL;
#line 576 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			e = _inner_error_;
#line 576 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_inner_error_ = NULL;
#line 579 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp6_ = e;
#line 579 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_tmp7_ = _tmp6_->message;
#line 579 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			g_warning ("util-app.vala:579: Failed to find system timezone: %s", _tmp7_);
#line 581 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			result = NULL;
#line 581 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_error_free0 (e);
#line 581 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			_g_error_free0 (e);
#line 581 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
			return result;
#line 6004 "util-app.c"
		}
		__finally93:
#line 576 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (e);
#line 576 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_error_free0 (e);
#line 576 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 576 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_clear_error (&_inner_error_);
#line 576 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return NULL;
#line 6017 "util-app.c"
	}
	__finally92:
#line 571 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 571 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_clear_error (&_inner_error_);
#line 571 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return NULL;
#line 6026 "util-app.c"
}


gchar* boxes_get_timezone_from_systemd (GError** error) {
	gchar* result = NULL;
	BoxesFdotimedate1* timedate = NULL;
	BoxesFdotimedate1* _tmp0_ = NULL;
	BoxesFdotimedate1* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
	BoxesFdotimedate1* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	GError * _inner_error_ = NULL;
#line 587 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = g_initable_new (BOXES_FDO_TYPE_TIMEDATE1_PROXY, NULL, &_inner_error_, "g-flags", 0, "g-name", "org.freedesktop.timedate1", "g-bus-type", G_BUS_TYPE_SYSTEM, "g-object-path", "/org/freedesktop/timedate1", "g-interface-name", "org.freedesktop.timedate1", NULL);
#line 587 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	timedate = (BoxesFdotimedate1*) _tmp0_;
#line 587 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_inner_error_ != NULL) {
#line 587 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_propagate_error (error, _inner_error_);
#line 587 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return NULL;
#line 6053 "util-app.c"
	}
#line 590 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = timedate;
#line 590 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = boxes_fdo_timedate1_get_timezone (_tmp1_);
#line 590 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = _tmp2_;
#line 590 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_ = _tmp3_;
#line 590 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = _tmp4_ == NULL;
#line 590 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (_tmp4_);
#line 590 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp5_) {
#line 6069 "util-app.c"
		GError* _tmp6_ = NULL;
#line 591 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp6_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, "Failed to get timezone from systemd");
#line 591 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_inner_error_ = _tmp6_;
#line 591 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_propagate_error (error, _inner_error_);
#line 591 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (timedate);
#line 591 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return NULL;
#line 6081 "util-app.c"
	}
#line 593 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp7_ = timedate;
#line 593 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp8_ = boxes_fdo_timedate1_get_timezone (_tmp7_);
#line 593 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp9_ = _tmp8_;
#line 593 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = _tmp9_;
#line 593 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (timedate);
#line 593 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 6095 "util-app.c"
}


gchar* boxes_get_timezone_from_linux (GError** error) {
	gchar* result = NULL;
	GFile* file = NULL;
	GFile* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	GFileInfo* info = NULL;
	GFileInfo* _tmp3_ = NULL;
	gchar* target = NULL;
	GFileInfo* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
	gchar** tokens = NULL;
	const gchar* _tmp9_ = NULL;
	gchar** _tmp10_ = NULL;
	gchar** _tmp11_ = NULL;
	gint tokens_length1 = 0;
	gint _tokens_size_ = 0;
	gboolean _tmp12_ = FALSE;
	gchar** _tmp13_ = NULL;
	gint _tmp13__length1 = 0;
	gboolean _tmp15_ = FALSE;
	gchar** _tmp18_ = NULL;
	gint _tmp18__length1 = 0;
	const gchar* _tmp19_ = NULL;
	gchar* _tmp20_ = NULL;
	GError * _inner_error_ = NULL;
#line 599 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = g_file_new_for_path (BOXES_TZ_FILE);
#line 599 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	file = _tmp0_;
#line 600 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = g_file_query_exists (file, NULL);
#line 600 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (!_tmp1_) {
#line 6134 "util-app.c"
		GError* _tmp2_ = NULL;
#line 601 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp2_ = g_error_new (BOXES_ERROR, BOXES_ERROR_INVALID, "Timezone file not found in expected location '%s'", BOXES_TZ_FILE);
#line 601 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_inner_error_ = _tmp2_;
#line 601 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_propagate_error (error, _inner_error_);
#line 601 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (file);
#line 601 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return NULL;
#line 6146 "util-app.c"
	}
#line 603 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = g_file_query_info (file, G_FILE_ATTRIBUTE_STANDARD_SYMLINK_TARGET, G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS, NULL, &_inner_error_);
#line 603 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	info = _tmp3_;
#line 603 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_inner_error_ != NULL) {
#line 603 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_propagate_error (error, _inner_error_);
#line 603 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (file);
#line 603 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return NULL;
#line 6160 "util-app.c"
	}
#line 604 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_ = info;
#line 604 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp5_ = g_file_info_get_symlink_target (_tmp4_);
#line 604 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp6_ = g_strdup (_tmp5_);
#line 604 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	target = _tmp6_;
#line 605 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp7_ = target;
#line 605 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp7_ == NULL) {
#line 6174 "util-app.c"
		GError* _tmp8_ = NULL;
#line 606 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp8_ = g_error_new (BOXES_ERROR, BOXES_ERROR_INVALID, "Timezone file '%s' is expected to be a symlink", BOXES_TZ_FILE);
#line 606 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_inner_error_ = _tmp8_;
#line 606 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_propagate_error (error, _inner_error_);
#line 606 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (target);
#line 606 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (info);
#line 606 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (file);
#line 606 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return NULL;
#line 6190 "util-app.c"
	}
#line 608 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp9_ = target;
#line 608 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp11_ = _tmp10_ = g_strsplit (_tmp9_, "zoneinfo/", 0);
#line 608 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	tokens = _tmp11_;
#line 608 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	tokens_length1 = _vala_array_length (_tmp10_);
#line 608 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tokens_size_ = tokens_length1;
#line 609 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp13_ = tokens;
#line 609 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp13__length1 = tokens_length1;
#line 609 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp13_ == NULL) {
#line 609 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp12_ = TRUE;
#line 6210 "util-app.c"
	} else {
		gchar** _tmp14_ = NULL;
		gint _tmp14__length1 = 0;
#line 609 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp14_ = tokens;
#line 609 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp14__length1 = tokens_length1;
#line 609 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp12_ = _tmp14__length1 < 2;
#line 6220 "util-app.c"
	}
#line 609 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp15_ = _tmp12_;
#line 609 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp15_) {
#line 6226 "util-app.c"
		const gchar* _tmp16_ = NULL;
		GError* _tmp17_ = NULL;
#line 610 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp16_ = target;
#line 610 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp17_ = g_error_new (BOXES_ERROR, BOXES_ERROR_INVALID, "Timezone file in unexpected location '%s'", _tmp16_);
#line 610 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_inner_error_ = _tmp17_;
#line 610 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		g_propagate_error (error, _inner_error_);
#line 610 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		tokens = (_vala_array_free (tokens, tokens_length1, (GDestroyNotify) g_free), NULL);
#line 610 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_free0 (target);
#line 610 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (info);
#line 610 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (file);
#line 610 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		return NULL;
#line 6247 "util-app.c"
	}
#line 612 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp18_ = tokens;
#line 612 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp18__length1 = tokens_length1;
#line 612 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp19_ = _tmp18_[1];
#line 612 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp20_ = g_strdup (_tmp19_);
#line 612 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = _tmp20_;
#line 612 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	tokens = (_vala_array_free (tokens, tokens_length1, (GDestroyNotify) g_free), NULL);
#line 612 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (target);
#line 612 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (info);
#line 612 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_object_unref0 (file);
#line 612 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 6269 "util-app.c"
}


gboolean boxes_is_mime_type (const gchar* filename, const gchar* mime_type) {
	gboolean result = FALSE;
	gchar* file_type = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* supertype = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
#line 615 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (filename != NULL, FALSE);
#line 615 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (mime_type != NULL, FALSE);
#line 616 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = filename;
#line 616 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = g_content_type_guess (_tmp0_, NULL, (gsize) 0, NULL);
#line 616 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	file_type = _tmp1_;
#line 617 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = mime_type;
#line 617 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp3_ = g_content_type_from_mime_type (_tmp2_);
#line 617 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	supertype = _tmp3_;
#line 619 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp4_ = g_content_type_is_a (file_type, supertype);
#line 619 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = _tmp4_;
#line 619 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (supertype);
#line 619 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_g_free0 (file_type);
#line 619 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 6308 "util-app.c"
}


gchar* boxes_uuid_generate (void) {
	gchar* result = NULL;
	guchar* udn = NULL;
	guchar* _tmp0_ = NULL;
	gint udn_length1 = 0;
	gint _udn_size_ = 0;
	guchar* id = NULL;
	guchar* _tmp1_ = NULL;
	gint id_length1 = 0;
	gint _id_size_ = 0;
	gchar* _tmp2_ = NULL;
#line 631 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = g_new0 (guchar, 50);
#line 631 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	udn = _tmp0_;
#line 631 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	udn_length1 = 50;
#line 631 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_udn_size_ = udn_length1;
#line 632 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = g_new0 (guchar, 16);
#line 632 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	id = _tmp1_;
#line 632 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	id_length1 = 16;
#line 632 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_id_size_ = id_length1;
#line 634 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	uuid_generate (id);
#line 635 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	uuid_unparse (id, udn);
#line 637 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = g_strdup ((const gchar*) udn);
#line 637 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = _tmp2_;
#line 637 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	id = (g_free (id), NULL);
#line 637 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	udn = (g_free (udn), NULL);
#line 637 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 6353 "util-app.c"
}


GIcon* boxes_create_symbolic_emblem (const gchar* name) {
	GIcon* result = NULL;
	GIcon* pix = NULL;
	const gchar* _tmp0_ = NULL;
	GIcon* _tmp1_ = NULL;
	GIcon* _tmp2_ = NULL;
#line 641 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 642 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp0_ = name;
#line 642 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp1_ = gd_create_symbolic_icon (_tmp0_, 128);
#line 642 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	pix = _tmp1_;
#line 644 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	_tmp2_ = pix;
#line 644 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	if (_tmp2_ == NULL) {
#line 6375 "util-app.c"
		const gchar* _tmp3_ = NULL;
		GThemedIcon* _tmp4_ = NULL;
#line 645 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp3_ = name;
#line 645 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_tmp4_ = (GThemedIcon*) g_themed_icon_new (_tmp3_);
#line 645 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		_g_object_unref0 (pix);
#line 645 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
		pix = (GIcon*) _tmp4_;
#line 6386 "util-app.c"
	}
#line 647 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	result = pix;
#line 647 "/home/zeenix/checkout/gnome/gnome-boxes/src/util-app.vala"
	return result;
#line 6392 "util-app.c"
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if ((array != NULL) && (destroy_func != NULL)) {
#line 6399 "util-app.c"
		int i;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		for (i = 0; i < array_length; i = i + 1) {
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			if (((gpointer*) array)[i] != NULL) {
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				destroy_func (((gpointer*) array)[i]);
#line 6407 "util-app.c"
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_vala_array_destroy (array, array_length, destroy_func);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_free (array);
#line 6419 "util-app.c"
}


static gint _vala_array_length (gpointer array) {
	int length;
	length = 0;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (array) {
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		while (((gpointer*) array)[length]) {
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			length++;
#line 6432 "util-app.c"
		}
	}
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return length;
#line 6437 "util-app.c"
}



